(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    104367,       3633]*)
(*NotebookOutlinePosition[    105046,       3657]*)
(*  CellTagsIndexPosition[    105002,       3653]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["Methoden der Bioinformatik",
    FontSize->24,
    FontWeight->"Bold"],
  StyleBox[" \n",
    FontSize->12],
  StyleBox["Eine Einf\[UDoubleDot]hrung",
    FontSize->18,
    FontWeight->"Bold"],
  StyleBox["\n",
    FontSize->12],
  StyleBox["Marc-Thorsten H\[UDoubleDot]tt und Manuel Dehnert",
    FontSize->12,
    FontWeight->"Bold"],
  StyleBox["\n",
    FontSize->12],
  StyleBox["Springer-Verlag 2006 (ISBN 3-540-25687-3)",
    FontSize->12,
    FontWeight->"Bold"],
  StyleBox["\n",
    FontSize->12]
}], "Subsubtitle"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "-Exkurs: Intron-Verteilung"
}], "Subtitle",
  Background->RGBColor[0.0901961, 0.462745, 0.396078]],

Cell[TextData[{
  "Die erste H\[UDoubleDot]rde der folgenden Untersuchung liegt in der \
Beschaffung der Daten. Wir verwenden hierzu den UCSC ",
  StyleBox["Genome Browser",
    FontSlant->"Italic"],
  ". Der Genome Browser an der ",
  StyleBox["University of California at Santa Cruz",
    FontSlant->"Italic"],
  " (UCSC) stellt Annotationen auf der Ebene ganzer Chromosomen bereit. \
\[CapitalUDoubleDot]ber ein Men\[UDoubleDot] l\[ADoubleDot]sst sich die gew\
\[UDoubleDot]nschte Information ausw\[ADoubleDot]hlen und als ASCII-Datei \
lokal speichern.",
  Cell[BoxData[
      \(TraditionalForm\`\^14\)]],
  " Die L\[ADoubleDot]ngenverteilung von Introns f\[UDoubleDot]r die Spezies \
Mensch liegt in der Datenbank nicht direkt vor, sie kann aber aus den \
Datenbank-Informationen abgeleitet werden. F\[UDoubleDot]r ein annotiertes \
Gen sind im Genome Browser neben dem Namen, der Position auf dem Strang und \
vielen anderen Informationen auch die Start- und Endpositionen der in diesem \
Gen enthaltenen Exons aufgelistet. Diese Positionen k\[ODoubleDot]nnen f\
\[UDoubleDot]r alle annotierten Gene eines Chromosoms abgefragt und \
gespeichert werden. \n\nDie lokal gespeicherten Daten f\[UDoubleDot]r das \
menschliche Chromosom 19 werden mit dem Befehl",
  StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12],
  StyleBox["ReadList",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12],
  "als W\[ODoubleDot]rter eingelesen (also mit der Einstellung ",
  StyleBox["Word",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ") und mit Hilfe des Befehls",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  StyleBox["ToExpression",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12],
  "in Zahlen umgewandelt."
}], "Text",
  FontSize->13],

Cell[TextData[{
  "F\[UDoubleDot]r das Einlesen einer Datei ist neben dem Dateinamen die \
Angabe des Verzeichnisses notwendig, in dem sie sich befindet. Mit den Befehl \
",
  StyleBox["SetDirectory[]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "  kann ein solches Verzeichnis spezifiziert werden. Dabei wird der Pfad in \
Anf\[UDoubleDot]hrungszeichen gesetzt.  Eine solche Angabe kann z.B. lauten:\n\
\n",
  StyleBox["SetDirectory[\"C:\\Mathematica-Exkurs Intron-Verteilung\"]; ",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"]
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13,
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \(<< Graphics`Graphics`\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"tmp01", "=", "\[IndentingNewLine]", 
        RowBox[{"ReadList", "[", 
          RowBox[{
          "\"\<HU_CCDS_chr19_May_2004_CUSC_exonStartEnd.txt\>\"", ",", "Word",
             ",", 
            RowBox[{
              StyleBox[
                RowBox[{"W", 
                  StyleBox["ordSeparators",
                    FontFamily->"Courier New"]}]], 
              StyleBox[" ",
                FontFamily->"Courier New"], 
              StyleBox["->",
                FontFamily->"Courier New",
                FontWeight->"Plain"], 
              
              StyleBox[\({"\<\t\>", "\<,\>", "\<\r\n\>", "\<\n\>", "\<\r\
\>"}\),
                FontFamily->"Courier New"]}], 
            ",", \(RecordLists \[Rule] True\)}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
    \(\(tmp02 = ToExpression[tmp01];\)\)], "Input"],

Cell[TextData[{
  "Wie an vielen Stellen in den ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "-Exkursen unterdr\[UDoubleDot]cken wir vielfach die Ausgabe durch das \
Semikolon am Zeilenende. Um die verschiedenen Optionen dieses Einlesebefehl \
besser zu verstehen, empfehlen wir auch hier, in der elektronischen Version \
des ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "-Exkurses von Hand \[CapitalADoubleDot]nderungen vorzunehmen und \
unterschiedliche Einstellungen auszuprobieren. F\[UDoubleDot]r jedes Gen \
liegt nun eine Liste mit Start- und Endpositionen der Exons vor. Dabei \
besteht die erste H\[ADoubleDot]lfte dieser Liste aus den Startpositionen und \
die zweite H\[ADoubleDot]lfte aus den Endpositionen. \n\nMit der Funktion",
  StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12],
  StyleBox["Take[list, i]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " fragt man die ersten ",
  StyleBox["i",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  StyleBox[" ",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  "Elemente der Variablen",
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  StyleBox["list",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  "ab. Auf die Liste",
  StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12],
  StyleBox["tmp02",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12],
  "angewendet hat man f\[UDoubleDot]r",
  StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12],
  StyleBox["i = 2",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  StyleBox[":",
    FontSize->12]
}], "Text",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(Take[tmp02, 2]\)], "Input"],

Cell[BoxData[
    \({{exonStarts\ #1, exonEnds}, {232387, 233133, 233751, 238473, 239019, 
        241951, 232537, 233310, 233809, 238751, 239171, 242066}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Dies ist eine Liste mit zwei Elementen. Diese Elemente sind, wie die \
Ausgabe zeigt, jedoch erneut Listen. Die L\[ADoubleDot]nge eines Introns \
ergibt sich nun aus der Differenz zwischen der Endposition eines Exons und \
der Startposition des darauf folgenden Exons. Damit wird die Startposition \
des ersten Exons und die Endposition des letzen Exons innerhalb eines Gens f\
\[UDoubleDot]r die weiteren Betrachtungen nicht mehr ben\[ODoubleDot]tigt und \
deshalb im Folgenden gel\[ODoubleDot]scht. Alle Gene, die nur aus einem Exons \
bestehen, werden in diesem Schritt auf die leere Menge abgebildet:",
  Cell[BoxData[
      \(TraditionalForm\`\^15\)]]
}], "Text",
  FontSize->13],

Cell[BoxData[
    \(\(tmp03 = Map[Delete[#, {{1}, {\(-1\)}}] &, tmp02];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tmp03[\([{1, 2}]\)]\)], "Input"],

Cell[BoxData[
    \({{}, {233133, 233751, 238473, 239019, 241951, 232537, 233310, 233809, 
        238751, 239171}}\)], "Output"]
}, Open  ]],

Cell["Diese leeren Mengen werden im n\[ADoubleDot]chsten Schritt entfernt:", \
"Text",
  FontSize->13],

Cell[BoxData[
    \(\(\(tmp04 = DeleteCases[tmp03, {}];\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  "Um die Differenzen zwischen den Start- und Endpositionen effizient zu \
bestimmen, wird eine Partitionierung der Liste in zwei H\[ADoubleDot]lften \
(und damit in Startpositionen und Endpositionen) vorgenommen. Die Berechnung \
der L\[ADoubleDot]ngen der Introns geschieht nun \[UDoubleDot]ber den Befehl \
",
  StyleBox["Subtract",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ", mit dem elementweise die Differenz zwischen der Liste der \
Startpositionen und der Liste der Endpositionen gebildet wird.",
  Cell[BoxData[
      \(TraditionalForm\`\^16\)]],
  " "
}], "Text",
  FontSize->13],

Cell[BoxData[
    \(\(tmp05 = Map[Partition[#, Length[#]/2] &, tmp04];\)\)], "Input"],

Cell[BoxData[
    \(\(tmp06 = 
        Table[Subtract[tmp05[\([i, 1]\)], tmp05[\([i, 2]\)]] - 2, {i, 1, 
              Length[tmp05]}] // Flatten;\)\)], "Input"],

Cell[TextData[{
  "Der am Ende dieser Kette von Operationen angewendete Befehl ",
  StyleBox["Flatten",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " entfernt die verbliebene Struktur in den Daten, und man \
erh\[ADoubleDot]lt die L\[ADoubleDot]ngen aller Introns f\[UDoubleDot]r das \
Chromosom 19 in Form einer Liste. \n\nEine Visualisierung der \
L\[ADoubleDot]ngenverteilung der Introns (\"Wie h\[ADoubleDot]ufig ist ein \
Intron der L\[ADoubleDot]nge ",
  StyleBox["n",
    FontSlant->"Italic"],
  "?\") in Form eines Histogramms erh\[ADoubleDot]lt man mit dem folgenden \
Befehlsblock. Zuerst wird der Bereich des Histogramms und die Breite der \
Balken (",
  StyleBox["binsize",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ") festgelegt. Dann erfolgt die Histogramm-Ausgabe."
}], "Text",
  FontSize->13],

Cell[BoxData[{
    \(\(min = 0;\)\), "\n", 
    \(\(max = 9000;\)\), "\n", 
    \(\(binsize = 150;\)\)}], "Input"],

Cell[BoxData[
    \(\(plIntrons = 
        Histogram[tmp06, HistogramScale \[Rule] False, 
          HistogramCategories \[Rule] Table[i, {i, min, max, binsize}], 
          HistogramRange -> {min, max}, Frame \[Rule] True, 
          DisplayFunction \[Rule] Identity];\)\)], "Input"],

Cell[TextData[{
  "Die Darstellung ist vorerst (mit der ",
  StyleBox["Option",
    FontFamily->"Times New Roman"],
  StyleBox[" DisplayFunction \[Rule] Identity",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  ") unterdr\[UDoubleDot]ckt und das Histogramm wird nur in die Variable ",
  StyleBox["plIntrons",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " geschrieben, da wir die Abbildung noch um ein weiteres Bildelement erg\
\[ADoubleDot]nzen wollen. M\[ODoubleDot]chte man die Verteilung der Abst\
\[ADoubleDot]nde nun einer quantitativen Analyse unterziehen, so gibt man \
eine Verteilungsfunktion als Modell vor, sch\[ADoubleDot]tzt die Parameter \
dieser Verteilung und sieht dann, ob das Modell in der Lage ist, die \
beobachteten Daten angemessen zu beschreiben. Im Verlauf dieses Kapitels \
haben wir bereits die geometrische Verteilung und ihr stetiges Analogon, die \
Exponentialverteilung, beschrieben. Obwohl die Verteilung der Introns diskret \
ist, gehen wir hier von einem kontinuierlichen Zustandsraum aus (eine \
Annahme, die in der Praxis sehr oft getroffen wird).",
  Cell[BoxData[
      \(TraditionalForm\`\^17\)]],
  "  Der einzige Parameter der Exponentialverteilung ist die Abklingrate ",
  StyleBox["\[Lambda]",
    FontVariations->{"CompatibilityType"->0}],
  ". Der Maximum-Likelihood-Sch\[ADoubleDot]tzer f\[UDoubleDot]r ",
  StyleBox["\[Lambda]",
    FontVariations->{"CompatibilityType"->0}],
  " ist durch den Kehrwert ",
  StyleBox["1/m",
    FontVariations->{"CompatibilityType"->0}],
  " des arithmetischen Mittels m = 1/n ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(i = 1\)\%n x\_i\)]],
  " gegeben, das sich in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " mit dem Befehl ",
  StyleBox["Mean",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " ermitteln l\[ADoubleDot]sst."
}], "Text",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Lambda] = 1/Mean[tmp06] // N\)], "Input"],

Cell[BoxData[
    \(0.0005483071481577624`\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Die Dichtefunktion der Exponentialverteilung aus Gleichung (2.47) hat die \
Fl\[ADoubleDot]che Eins unter der Kurve, w\[ADoubleDot]hrend die Fl\
\[ADoubleDot]che des Histogramms nicht auf Eins normiert ist. Um beide \
miteinander vergleichen zu k\[ODoubleDot]nnen, muss man eine Skalierung \
durchf\[UDoubleDot]hren. Wir werden hier die Dichtefunktion neu skalieren.",
  Cell[BoxData[
      \(TraditionalForm\`\^\(\(18\)\(\ \)\)\)]],
  " Dazu muss die Dichtefunktion mit der Anzahl der Beobachtungen und der \
Breite der Balken multipliziert werden. So erh\[ADoubleDot]lt man die \
skalierte Dichtefunktion als"
}], "Text",
  FontSize->13],

Cell[BoxData[
    \(\(number = Length[tmp06];\)\)], "Input"],

Cell[BoxData[
    \(fExpo[
        x_] := \(\(number\)\(*\)\(binsize\)\(*\)\(\[Lambda]\)\(*\)\(\
\[ExponentialE]\^\(\(-\[Lambda]\)*x\)\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(plExpo = 
        Plot[fExpo[x], {x, min + binsize/2, max - binsize/2}, 
          DisplayFunction \[Rule] Identity];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[plIntrons, plExpo, 
        DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.39609e-017 0.000111111 0.0147151 0.000467517 [
[.22222 -0.0125 -12 -9 ]
[.22222 -0.0125 12 0 ]
[.44444 -0.0125 -12 -9 ]
[.44444 -0.0125 12 0 ]
[.66667 -0.0125 -12 -9 ]
[.66667 -0.0125 12 0 ]
[.88889 -0.0125 -12 -9 ]
[.88889 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10822 -18 -4.5 ]
[-0.0125 .10822 0 4.5 ]
[-0.0125 .20172 -18 -4.5 ]
[-0.0125 .20172 0 4.5 ]
[-0.0125 .29523 -18 -4.5 ]
[-0.0125 .29523 0 4.5 ]
[-0.0125 .38873 -18 -4.5 ]
[-0.0125 .38873 0 4.5 ]
[-0.0125 .48223 -24 -4.5 ]
[-0.0125 .48223 0 4.5 ]
[-0.0125 .57574 -24 -4.5 ]
[-0.0125 .57574 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.22222 0 m
.22222 .00625 L
s
[(2000)] .22222 -0.0125 0 1 Mshowa
.44444 0 m
.44444 .00625 L
s
[(4000)] .44444 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(6000)] .66667 -0.0125 0 1 Mshowa
.88889 0 m
.88889 .00625 L
s
[(8000)] .88889 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.11111 0 m
.11111 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38889 0 m
.38889 .00375 L
s
.5 0 m
.5 .00375 L
s
.55556 0 m
.55556 .00375 L
s
.61111 0 m
.61111 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10822 m
.00625 .10822 L
s
[(200)] -0.0125 .10822 1 0 Mshowa
0 .20172 m
.00625 .20172 L
s
[(400)] -0.0125 .20172 1 0 Mshowa
0 .29523 m
.00625 .29523 L
s
[(600)] -0.0125 .29523 1 0 Mshowa
0 .38873 m
.00625 .38873 L
s
[(800)] -0.0125 .38873 1 0 Mshowa
0 .48223 m
.00625 .48223 L
s
[(1000)] -0.0125 .48223 1 0 Mshowa
0 .57574 m
.00625 .57574 L
s
[(1200)] -0.0125 .57574 1 0 Mshowa
.125 Mabswid
0 .03809 m
.00375 .03809 L
s
0 .06147 m
.00375 .06147 L
s
0 .08484 m
.00375 .08484 L
s
0 .13159 m
.00375 .13159 L
s
0 .15497 m
.00375 .15497 L
s
0 .17835 m
.00375 .17835 L
s
0 .2251 m
.00375 .2251 L
s
0 .24847 m
.00375 .24847 L
s
0 .27185 m
.00375 .27185 L
s
0 .3186 m
.00375 .3186 L
s
0 .34198 m
.00375 .34198 L
s
0 .36535 m
.00375 .36535 L
s
0 .4121 m
.00375 .4121 L
s
0 .43548 m
.00375 .43548 L
s
0 .45886 m
.00375 .45886 L
s
0 .50561 m
.00375 .50561 L
s
0 .52898 m
.00375 .52898 L
s
0 .55236 m
.00375 .55236 L
s
0 .59911 m
.00375 .59911 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.22222 .61178 m
.22222 .61803 L
s
.44444 .61178 m
.44444 .61803 L
s
.66667 .61178 m
.66667 .61803 L
s
.88889 .61178 m
.88889 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.11111 .61428 m
.11111 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38889 .61428 m
.38889 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.55556 .61428 m
.55556 .61803 L
s
.61111 .61428 m
.61111 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.77778 .61428 m
.77778 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10822 m
1 .10822 L
s
.99375 .20172 m
1 .20172 L
s
.99375 .29523 m
1 .29523 L
s
.99375 .38873 m
1 .38873 L
s
.99375 .48223 m
1 .48223 L
s
.99375 .57574 m
1 .57574 L
s
.125 Mabswid
.99625 .03809 m
1 .03809 L
s
.99625 .06147 m
1 .06147 L
s
.99625 .08484 m
1 .08484 L
s
.99625 .13159 m
1 .13159 L
s
.99625 .15497 m
1 .15497 L
s
.99625 .17835 m
1 .17835 L
s
.99625 .2251 m
1 .2251 L
s
.99625 .24847 m
1 .24847 L
s
.99625 .27185 m
1 .27185 L
s
.99625 .3186 m
1 .3186 L
s
.99625 .34198 m
1 .34198 L
s
.99625 .36535 m
1 .36535 L
s
.99625 .4121 m
1 .4121 L
s
.99625 .43548 m
1 .43548 L
s
.99625 .45886 m
1 .45886 L
s
.99625 .50561 m
1 .50561 L
s
.99625 .52898 m
1 .52898 L
s
.99625 .55236 m
1 .55236 L
s
.99625 .59911 m
1 .59911 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .60332 L
.01667 .60332 L
.01667 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .60332 L
.01667 .60332 L
.01667 .01472 L
0 .01472 L
s
1 0 0 r
.01667 .01472 m
.01667 .3733 L
.03333 .3733 L
.03333 .01472 L
F
0 g
.01667 .01472 m
.01667 .3733 L
.03333 .3733 L
.03333 .01472 L
.01667 .01472 L
s
1 0 0 r
.03333 .01472 m
.03333 .25362 L
.05 .25362 L
.05 .01472 L
F
0 g
.03333 .01472 m
.03333 .25362 L
.05 .25362 L
.05 .01472 L
.03333 .01472 L
s
1 0 0 r
.05 .01472 m
.05 .19003 L
.06667 .19003 L
.06667 .01472 L
F
0 g
.05 .01472 m
.05 .19003 L
.06667 .19003 L
.06667 .01472 L
.05 .01472 L
s
1 0 0 r
.06667 .01472 m
.06667 .1545 L
.08333 .1545 L
.08333 .01472 L
F
0 g
.06667 .01472 m
.06667 .1545 L
.08333 .1545 L
.08333 .01472 L
.06667 .01472 L
s
1 0 0 r
.08333 .01472 m
.08333 .13066 L
.1 .13066 L
.1 .01472 L
F
0 g
.08333 .01472 m
.08333 .13066 L
.1 .13066 L
.1 .01472 L
.08333 .01472 L
s
1 0 0 r
.1 .01472 m
.1 .12037 L
.11667 .12037 L
.11667 .01472 L
F
0 g
.1 .01472 m
.1 .12037 L
.11667 .12037 L
.11667 .01472 L
.1 .01472 L
s
1 0 0 r
.11667 .01472 m
.11667 .10214 L
.13333 .10214 L
.13333 .01472 L
F
0 g
.11667 .01472 m
.11667 .10214 L
.13333 .10214 L
.13333 .01472 L
.11667 .01472 L
s
1 0 0 r
.13333 .01472 m
.13333 .09887 L
.15 .09887 L
.15 .01472 L
F
0 g
.13333 .01472 m
.13333 .09887 L
.15 .09887 L
.15 .01472 L
.13333 .01472 L
s
1 0 0 r
.15 .01472 m
.15 .08905 L
.16667 .08905 L
.16667 .01472 L
F
0 g
.15 .01472 m
.15 .08905 L
.16667 .08905 L
.16667 .01472 L
.15 .01472 L
s
1 0 0 r
.16667 .01472 m
.16667 .08344 L
.18333 .08344 L
.18333 .01472 L
F
0 g
.16667 .01472 m
.16667 .08344 L
.18333 .08344 L
.18333 .01472 L
.16667 .01472 L
s
1 0 0 r
.18333 .01472 m
.18333 .07315 L
.2 .07315 L
.2 .01472 L
F
0 g
.18333 .01472 m
.18333 .07315 L
.2 .07315 L
.2 .01472 L
.18333 .01472 L
s
1 0 0 r
.2 .01472 m
.2 .06941 L
.21667 .06941 L
.21667 .01472 L
F
0 g
.2 .01472 m
.2 .06941 L
.21667 .06941 L
.21667 .01472 L
.2 .01472 L
s
1 0 0 r
.21667 .01472 m
.21667 .06567 L
.23333 .06567 L
.23333 .01472 L
F
0 g
.21667 .01472 m
.21667 .06567 L
.23333 .06567 L
.23333 .01472 L
.21667 .01472 L
s
1 0 0 r
.23333 .01472 m
.23333 .06941 L
.25 .06941 L
.25 .01472 L
F
0 g
.23333 .01472 m
.23333 .06941 L
.25 .06941 L
.25 .01472 L
.23333 .01472 L
s
1 0 0 r
.25 .01472 m
.25 .05539 L
.26667 .05539 L
.26667 .01472 L
F
0 g
.25 .01472 m
.25 .05539 L
.26667 .05539 L
.26667 .01472 L
.25 .01472 L
s
1 0 0 r
.26667 .01472 m
.26667 .05258 L
.28333 .05258 L
.28333 .01472 L
F
0 g
.26667 .01472 m
.26667 .05258 L
.28333 .05258 L
.28333 .01472 L
.26667 .01472 L
s
1 0 0 r
.28333 .01472 m
.28333 .0409 L
.3 .0409 L
.3 .01472 L
F
0 g
.28333 .01472 m
.28333 .0409 L
.3 .0409 L
.3 .01472 L
.28333 .01472 L
s
1 0 0 r
.3 .01472 m
.3 .0624 L
.31667 .0624 L
.31667 .01472 L
F
0 g
.3 .01472 m
.3 .0624 L
.31667 .0624 L
.31667 .01472 L
.3 .01472 L
s
1 0 0 r
.31667 .01472 m
.31667 .04838 L
.33333 .04838 L
.33333 .01472 L
F
0 g
.31667 .01472 m
.31667 .04838 L
.33333 .04838 L
.33333 .01472 L
.31667 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .04464 L
.35 .04464 L
.35 .01472 L
F
0 g
.33333 .01472 m
.33333 .04464 L
.35 .04464 L
.35 .01472 L
.33333 .01472 L
s
1 0 0 r
.35 .01472 m
.35 .05258 L
.36667 .05258 L
.36667 .01472 L
F
0 g
.35 .01472 m
.35 .05258 L
.36667 .05258 L
.36667 .01472 L
.35 .01472 L
s
1 0 0 r
.36667 .01472 m
.36667 .0423 L
.38333 .0423 L
.38333 .01472 L
F
0 g
.36667 .01472 m
.36667 .0423 L
.38333 .0423 L
.38333 .01472 L
.36667 .01472 L
s
1 0 0 r
.38333 .01472 m
.38333 .04417 L
.4 .04417 L
.4 .01472 L
F
0 g
.38333 .01472 m
.38333 .04417 L
.4 .04417 L
.4 .01472 L
.38333 .01472 L
s
1 0 0 r
.4 .01472 m
.4 .04183 L
.41667 .04183 L
.41667 .01472 L
F
0 g
.4 .01472 m
.4 .04183 L
.41667 .04183 L
.41667 .01472 L
.4 .01472 L
s
1 0 0 r
.41667 .01472 m
.41667 .03342 L
.43333 .03342 L
.43333 .01472 L
F
0 g
.41667 .01472 m
.41667 .03342 L
.43333 .03342 L
.43333 .01472 L
.41667 .01472 L
s
1 0 0 r
.43333 .01472 m
.43333 .03575 L
.45 .03575 L
.45 .01472 L
F
0 g
.43333 .01472 m
.43333 .03575 L
.45 .03575 L
.45 .01472 L
.43333 .01472 L
s
1 0 0 r
.45 .01472 m
.45 .03482 L
.46667 .03482 L
.46667 .01472 L
F
0 g
.45 .01472 m
.45 .03482 L
.46667 .03482 L
.46667 .01472 L
.45 .01472 L
s
1 0 0 r
.46667 .01472 m
.46667 .03061 L
.48333 .03061 L
.48333 .01472 L
F
0 g
.46667 .01472 m
.46667 .03061 L
.48333 .03061 L
.48333 .01472 L
.46667 .01472 L
s
1 0 0 r
.48333 .01472 m
.48333 .025 L
.5 .025 L
.5 .01472 L
F
0 g
.48333 .01472 m
.48333 .025 L
.5 .025 L
.5 .01472 L
.48333 .01472 L
s
1 0 0 r
.5 .01472 m
.5 .03201 L
.51667 .03201 L
.51667 .01472 L
F
0 g
.5 .01472 m
.5 .03201 L
.51667 .03201 L
.51667 .01472 L
.5 .01472 L
s
1 0 0 r
.51667 .01472 m
.51667 .025 L
.53333 .025 L
.53333 .01472 L
F
0 g
.51667 .01472 m
.51667 .025 L
.53333 .025 L
.53333 .01472 L
.51667 .01472 L
s
1 0 0 r
.53333 .01472 m
.53333 .02781 L
.55 .02781 L
.55 .01472 L
F
0 g
.53333 .01472 m
.53333 .02781 L
.55 .02781 L
.55 .01472 L
.53333 .01472 L
s
1 0 0 r
.55 .01472 m
.55 .02968 L
.56667 .02968 L
.56667 .01472 L
F
0 g
.55 .01472 m
.55 .02968 L
.56667 .02968 L
.56667 .01472 L
.55 .01472 L
s
1 0 0 r
.56667 .01472 m
.56667 .02594 L
.58333 .02594 L
.58333 .01472 L
F
0 g
.56667 .01472 m
.56667 .02594 L
.58333 .02594 L
.58333 .01472 L
.56667 .01472 L
s
1 0 0 r
.58333 .01472 m
.58333 .02594 L
.6 .02594 L
.6 .01472 L
F
0 g
.58333 .01472 m
.58333 .02594 L
.6 .02594 L
.6 .01472 L
.58333 .01472 L
s
1 0 0 r
.6 .01472 m
.6 .0236 L
.61667 .0236 L
.61667 .01472 L
F
0 g
.6 .01472 m
.6 .0236 L
.61667 .0236 L
.61667 .01472 L
.6 .01472 L
s
1 0 0 r
.61667 .01472 m
.61667 .02313 L
.63333 .02313 L
.63333 .01472 L
F
0 g
.61667 .01472 m
.61667 .02313 L
.63333 .02313 L
.63333 .01472 L
.61667 .01472 L
s
1 0 0 r
.63333 .01472 m
.63333 .02173 L
.65 .02173 L
.65 .01472 L
F
0 g
.63333 .01472 m
.63333 .02173 L
.65 .02173 L
.65 .01472 L
.63333 .01472 L
s
1 0 0 r
.65 .01472 m
.65 .0222 L
.66667 .0222 L
.66667 .01472 L
F
0 g
.65 .01472 m
.65 .0222 L
.66667 .0222 L
.66667 .01472 L
.65 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .02313 L
.68333 .02313 L
.68333 .01472 L
F
0 g
.66667 .01472 m
.66667 .02313 L
.68333 .02313 L
.68333 .01472 L
.66667 .01472 L
s
1 0 0 r
.68333 .01472 m
.68333 .025 L
.7 .025 L
.7 .01472 L
F
0 g
.68333 .01472 m
.68333 .025 L
.7 .025 L
.7 .01472 L
.68333 .01472 L
s
1 0 0 r
.7 .01472 m
.7 .01752 L
.71667 .01752 L
.71667 .01472 L
F
0 g
.7 .01472 m
.7 .01752 L
.71667 .01752 L
.71667 .01472 L
.7 .01472 L
s
1 0 0 r
.71667 .01472 m
.71667 .01892 L
.73333 .01892 L
.73333 .01472 L
F
0 g
.71667 .01472 m
.71667 .01892 L
.73333 .01892 L
.73333 .01472 L
.71667 .01472 L
s
1 0 0 r
.73333 .01472 m
.73333 .02126 L
.75 .02126 L
.75 .01472 L
F
0 g
.73333 .01472 m
.73333 .02126 L
.75 .02126 L
.75 .01472 L
.73333 .01472 L
s
1 0 0 r
.75 .01472 m
.75 .02313 L
.76667 .02313 L
.76667 .01472 L
F
0 g
.75 .01472 m
.75 .02313 L
.76667 .02313 L
.76667 .01472 L
.75 .01472 L
s
1 0 0 r
.76667 .01472 m
.76667 .01939 L
.78333 .01939 L
.78333 .01472 L
F
0 g
.76667 .01472 m
.76667 .01939 L
.78333 .01939 L
.78333 .01472 L
.76667 .01472 L
s
1 0 0 r
.78333 .01472 m
.78333 .02033 L
.8 .02033 L
.8 .01472 L
F
0 g
.78333 .01472 m
.78333 .02033 L
.8 .02033 L
.8 .01472 L
.78333 .01472 L
s
1 0 0 r
.8 .01472 m
.8 .02079 L
.81667 .02079 L
.81667 .01472 L
F
0 g
.8 .01472 m
.8 .02079 L
.81667 .02079 L
.81667 .01472 L
.8 .01472 L
s
1 0 0 r
.81667 .01472 m
.81667 .01799 L
.83333 .01799 L
.83333 .01472 L
F
0 g
.81667 .01472 m
.81667 .01799 L
.83333 .01799 L
.83333 .01472 L
.81667 .01472 L
s
1 0 0 r
.83333 .01472 m
.83333 .01986 L
.85 .01986 L
.85 .01472 L
F
0 g
.83333 .01472 m
.83333 .01986 L
.85 .01986 L
.85 .01472 L
.83333 .01472 L
s
1 0 0 r
.85 .01472 m
.85 .01846 L
.86667 .01846 L
.86667 .01472 L
F
0 g
.85 .01472 m
.85 .01846 L
.86667 .01846 L
.86667 .01472 L
.85 .01472 L
s
1 0 0 r
.86667 .01472 m
.86667 .01799 L
.88333 .01799 L
.88333 .01472 L
F
0 g
.86667 .01472 m
.86667 .01799 L
.88333 .01799 L
.88333 .01472 L
.86667 .01472 L
s
1 0 0 r
.88333 .01472 m
.88333 .01752 L
.9 .01752 L
.9 .01472 L
F
0 g
.88333 .01472 m
.88333 .01752 L
.9 .01752 L
.9 .01472 L
.88333 .01472 L
s
1 0 0 r
.9 .01472 m
.9 .01659 L
.91667 .01659 L
.91667 .01472 L
F
0 g
.9 .01472 m
.9 .01659 L
.91667 .01659 L
.91667 .01472 L
.9 .01472 L
s
1 0 0 r
.91667 .01472 m
.91667 .01892 L
.93333 .01892 L
.93333 .01472 L
F
0 g
.91667 .01472 m
.91667 .01892 L
.93333 .01892 L
.93333 .01472 L
.91667 .01472 L
s
1 0 0 r
.93333 .01472 m
.93333 .01612 L
.95 .01612 L
.95 .01472 L
F
0 g
.93333 .01472 m
.93333 .01612 L
.95 .01612 L
.95 .01472 L
.93333 .01472 L
s
1 0 0 r
.95 .01472 m
.95 .01705 L
.96667 .01705 L
.96667 .01472 L
F
0 g
.95 .01472 m
.95 .01705 L
.96667 .01705 L
.96667 .01472 L
.95 .01472 L
s
1 0 0 r
.96667 .01472 m
.96667 .01846 L
.98333 .01846 L
.98333 .01472 L
F
0 g
.96667 .01472 m
.96667 .01846 L
.98333 .01846 L
.98333 .01472 L
.96667 .01472 L
s
1 0 0 r
.98333 .01472 m
.98333 .01799 L
1 .01799 L
1 .01472 L
F
0 g
.98333 .01472 m
.98333 .01799 L
1 .01799 L
1 .01472 L
.98333 .01472 L
s
.00833 .24871 m
.04822 .2069 L
.09173 .16977 L
.13259 .14146 L
.17188 .11912 L
.21371 .09965 L
.25397 .08434 L
.29676 .07109 L
.33799 .06071 L
.37765 .05253 L
.41984 .04543 L
.46047 .03985 L
.49954 .03544 L
.54113 .03159 L
.58117 .02857 L
.62373 .02594 L
.66473 .02389 L
.70416 .02227 L
.74613 .02085 L
.78653 .01974 L
.82946 .01878 L
.87083 .01803 L
.91064 .01744 L
.95297 .01693 L
.99167 .01654 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{287.188, 177.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004O0000/B000`400?l00000o`00003oo`3ooolP
0?ooo`00o`3ooolP0?ooo`00o`3ooolP0?ooo`00B@3oool4000000<0oooo0P0000040?ooo`800000
103oool2000002L0oooo0`0000020?ooo`800000103oool2000000@0oooo0P00000T0?ooo`<00000
103oool2000000@0oooo0P0000040?ooo`8000009P3oool2000000@0oooo0P0000040?ooo`800000
103oool2000001@0oooo00190?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool08@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000T0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000001<0oooo001:0?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002@0oooo
1@0000001@3oool000000?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`00000S0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002@0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000004`3oool004/0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0R
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000002<0oooo0`0000030?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000U0?ooo`800000
0`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000004`3oool004T0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000009@3oool00`000000
oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`00000T0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002@0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000004`3oool004X0oooo0P0000040?ooo`800000103oool2000000@0oooo
0P00000W0?ooo`8000000`3oool2000000@0oooo0P0000040?ooo`8000009@3oool3000000<0oooo
0P0000040?ooo`800000103oool2000002H0oooo0P0000040?ooo`800000103oool2000000@0oooo
0P00000D0?ooo`00o`3ooolP0?ooo`00o`3ooolP0?ooo`00o`3ooolP0?ooo`00o`3ooolP0?ooo`00
o`3ooolP0?ooo`006`3ooooo000000D00000000K0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`400000000D0?ooo`8000001@3oool00`00
0000oooo0?ooo`0f0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0=P3oool00`00
0000oooo0?ooo`0g0?ooo`030000003oool0oooo01X0oooo0@00000001<0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`3o0?ooo`40oooo0@00000001<0oooo00@000000?ooo`3o
ool00000103ooooo000000D00000000C0?ooo`040000003oool0oooo000000@0oooo00D000000?l0
003o0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0003o0000o`000000
00030?l000030000003o0000o`000080o`0000D000000?l0003o0000o`00000000030?l000030000
003o0000o`000080o`0000D000000?l0003o0000o`00000000030?l000030000003o0000o`000080
o`0000D000000?l0003o0000o`00000000030?l000050000003o0000o`000?l000000000103o0000
1@000000o`000?l0003o0000000000<0o`0000<000000?l0003o00000P3o00001@000000o`000?l0
003o0000000000<0o`0000<000000?l0003o00000P3o00001@000000o`000?l0003o0000000000<0
o`0000<000000?l0003o00000P3o00001@000000o`000?l0003o0000000000<0o`0000<000000?l0
003o00000P3o00001@000000o`000?l0003o0000000000<0o`0000D000000?l0003o0000o`000000
00040?l000050000003o0000o`000?l0000000000`3o00000`000000o`000?l000020?l000050000
003o0000o`000?l0000000000`3o00000`000000o`000?l000020?l000050000003o0000o`000?l0
000000000`3o00000`000000o`000?l000020?l000040000003o0000o`000?l000X000000`3o0000
10000000o`000?l0003o000n000000004`3oool010000000oooo0?ooo`0000040?ooo`050000003o
0000o`000?l0000000000`3o00000`000000o`000?l000020?l000050000003o0000o`000?l00000
00000`3o00000`000000o`000?l000020?l000050000003o0000o`000?l0000000000`3o00000`00
0000o`000?l000020?l000050000003o0000o`000?l0000000000`3o00000`000000o`000?l00002
0?l000050000003o0000o`000?l0000000000`3o00001@000000o`000?l0003o0000000000@0o`00
00D000000?l0003o0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0003o
0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0003o0000o`0000000003
0?l000030000003o0000o`000080o`0000D000000?l0003o0000o`00000000030?l000030000003o
0000o`000080o`0000D000000?l0003o0000o`00000000030?l000050000003o0000o`000?l00000
0000103o00001@000000o`000?l0003o0000000000<0o`0000<000000?l0003o00000P3o00001000
0000o`000?l0003o000/000000<0oooo2P0000030?ooo`H000009P3oool100000000503oool20000
00D0oooo00D000000?l0003o0000o`00000000030?l000030000003o0000o`000080o`0000D00000
0?l0003o0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0003o0000o`00
000000030?l000030000003o0000o`000080o`0000D000000?l0003o0000o`00000000030?l00003
0000003o0000o`000080o`0000D000000?l0003o0000o`00000000030?l000050000003o0000o`00
0?l000000000103o00001@000000o`000?l0003o0000000000<0o`0000<000000?l0003o00000P3o
00001@000000o`000?l0003o0000000000<0o`0000<000000?l0003o00000P3o00001@000000o`00
0?l0003o0000000000<0o`0000<000000?l0003o00000P3o00001@000000o`000?l0003o00000000
00<0o`0000<000000?l0003o00000P3o000010000000o`000?l0003o0005000000<0o`001P000003
0?l000040000003o0000o`000?l002@00000C@3oool1000000006`3oool01@000000o`000?l0003o
0000000000<0o`0000<000000?l0003o00000P3o00001@000000o`000?l0003o0000000000<0o`00
00<000000?l0003o00000P3o00001@000000o`000?l0003o0000000000<0o`0000<000000?l0003o
00000P3o00001@000000o`000?l0003o0000000000<0o`0000<000000?l0003o00000P3o00001@00
0000o`000?l0003o0000000000<0o`0000D000000?l0003o0000o`00000000040?l000050000003o
0000o`000?l0000000000`3o00000`000000o`000?l000020?l000050000003o0000o`000?l00000
00000`3o00000`000000o`000?l000020?l000050000003o0000o`000?l0000000000`3o00000`00
0000o`000?l000020?l000050000003o0000o`000?l0000000000`3o00000`000000o`000?l00002
0?l000D000000`3oool01@000000o`000?l0003o0000000000@0oooo4P00001W0?ooo`400000000K
0?ooo`050000003o0000o`000?l0000000000`3o00000`000000o`000?l000020?l000050000003o
0000o`000?l0000000000`3o00000`000000o`000?l000020?l000050000003o0000o`000?l00000
00000`3o00000`000000o`000?l000020?l000050000003o0000o`000?l0000000000`3o00000`00
0000o`000?l000020?l000050000003o0000o`000?l0000000000`3o00001@000000o`000?l0003o
0000000000@0o`0000D000000?l0003o0000o`00000000030?l000030000003o0000o`000080o`00
00D000000?l0003o0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0003o
0000o`00000000030?l000030000003o0000o`000080o`001@0000030?l000H000001`3oool50000
00030?ooo`000000000000T00000L@3oool1000000006`3oool01@000000o`000?l0003o00000000
00<0o`0000<000000?l0003o00000P3o00001@000000o`000?l0003o0000000000<0o`0000<00000
0?l0003o00000P3o00001@000000o`000?l0003o0000000000<0o`0000<000000?l0003o00000P3o
00001@000000o`000?l0003o0000000000<0o`0000<000000?l0003o00000P3o00001@000000o`00
0?l0003o0000000000<0o`0000D000000?l0003o0000o`00000000040?l000050000003o0000o`00
0?l0000000000`3o00000`000000o`000?l000020?l000050000003o0000o`000?l0000000000`3o
00000`000000o`000?l000020?l000050000003o0000o`000?l0000000000`3o00000`000000o`00
0?l000020?l000040000003oool0oooo0?ooo`D00000203oool:000007/0oooo0P00000001/0oooo
00D000000?l0003o0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0003o
0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0003o0000o`0000000003
0?l000030000003o0000o`000080o`0000D000000?l0003o0000o`00000000030?l000030000003o
0000o`000080o`0000D000000?l0003o0000o`00000000030?l000050000003o0000o`000?l00000
0000103o000010000000o`000?l0003o0005000000@0o`0000D000000?l0003o0000o`0000000003
0?l000030000003o0000o`000080o`001@0000030?l000H000001@3oool;000008H0oooo0@000000
01/0oooo00D000000?l0003o0000o`00000000030?l000030000003o0000o`000080o`0000D00000
0?l0003o0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0003o0000o`00
000000030?l000030000003o0000o`000080o`0000D000000?l0003o0000o`00000000030?l00003
0000003o0000o`000080o`0000D000000?l0003o0000o`00000000030?l000050000003o0000o`00
0?l000000000103o00001@000000o`000?l0003o0000000000<0oooo00<000000?l0003o00000P3o
000010000000o`000?l0003o0005000000@0o`0000@000000?ooo`3oool0oooo1@0000020?ooo`P0
0000T@3oool1000000006`3oool01@000000o`000?l0003o0000000000<0o`0000<000000?l0003o
00000P3o00001@000000o`000?l0003o0000000000<0o`0000<000000?l0003o00000P3o00001@00
0000o`000?l0003o0000000000<0o`0000<000000?l0003o00000P3o00001@000000o`000?l0003o
0000000000<0o`0000<000000?l0003o00000P3o00001@000000o`000?l0003o0000000000<0o`00
00D000000?l0003o0000o`00000000040?l000050000003o0000o`000?l0000000000`3oool00`00
0000o`000?l000020?l000D000000`3oool00`000000o`000?l000020?l000030000003oool0oooo
0080oooo1P00002I0?ooo`400000000K0?ooo`050000003o0000o`000?l0000000000`3o00000`00
0000o`000?l000020?l000050000003o0000o`000?l0000000000`3o00000`000000o`000?l00002
0?l000050000003o0000o`000?l0000000000`3o00000`000000o`000?l000020?l000050000003o
0000o`000?l0000000000`3o00000`000000o`000?l000020?l000050000003o0000o`000?l00000
00000`3o00001@000000o`000?l0003o0000000000@0o`001@0000030?ooo`030000003o0000o`00
0080o`0000<000000?ooo`3oool01@3oool:000009l0oooo0@00000001/0oooo00D000000?l0003o
0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0003o0000o`0000000003
0?l000030000003o0000o`000080o`0000D000000?l0003o0000o`00000000030?l000030000003o
0000o`000080o`0000D000000?l0003o0000o`00000000030?l000030000003o0000o`000080o`00
00D000000?l0003o0000o`00000000030?l000040000003o0000o`000?l000H000001`3oool00`00
0000o`000?l000020?l000030000003oool0oooo00D0oooo1@00002T0?ooo`400000000K0?ooo`05
0000003o0000o`000?l0000000000`3o00000`000000o`000?l000020?l000050000003o0000o`00
0?l0000000000`3o00000`000000o`000?l000020?l000050000003o0000o`000?l0000000000`3o
00000`000000o`000?l000020?l000050000003o0000o`000?l0000000000`3o00000`000000o`00
0?l000020?l000050000003o0000o`000?l0000000000`3o00001@000000o`000?l0003o00000000
00`0oooo00<000000?l0003o00000P3o000010000000oooo0?ooo`3oool400000:P0oooo0P000000
01/0oooo00D000000?l0003o0000o`00000000030?l000030000003o0000o`000080o`0000D00000
0?l0003o0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0003o0000o`00
000000030?l000030000003o0000o`000080o`0000D000000?l0003o0000o`00000000030?l00003
0000003o0000o`000080o`0000@000000?l0003o0000o`001@0000030?l000030000003oool0oooo
00X0oooo2@00002]0?ooo`400000000K0?ooo`050000003o0000o`000?l0000000000`3o00000`00
0000o`000?l000020?l000050000003o0000o`000?l0000000000`3o00000`000000o`000?l00002
0?l000050000003o0000o`000?l0000000000`3o00000`000000o`000?l000020?l000050000003o
0000o`000?l0000000000`3o00000`000000o`000?l000020?l000D000000`3oool5000000h0oooo
1000002`0?ooo`400000000K0?ooo`050000003o0000o`000?l0000000000`3o00000`000000o`00
0?l000020?l000050000003o0000o`000?l0000000000`3o00000`000000o`000?l000020?l00005
0000003o0000o`000?l0000000000`3o00000`000000o`000?l000020?l000050000003o0000o`00
0?l0000000000`3o0006000001L0oooo0`00002d0?ooo`400000000K0?ooo`050000003o0000o`00
0?l0000000000`3o00000`000000o`000?l000020?l000050000003o0000o`000?l0000000000`3o
00000`000000o`000?l000020?l000050000003o0000o`000?l0000000000`3o00000`000000o`00
0?l000020?l000050000003o0000o`000?l0000000000`3o00000`000000oooo0?ooo`0F0?ooo`@0
0000]`3oool1000000006`3oool01@000000o`000?l0003o0000000000<0o`0000<000000?l0003o
00000P3o00001@000000o`000?l0003o0000000000<0o`0000<000000?l0003o00000P3o00001@00
0000o`000?l0003o0000000000<0o`0000<000000?l0003o00000P3o00001@000000o`000?l0003o
0000000000<0o`0000<000000?ooo`3oool04P3oool400000;/0oooo0@00000001/0oooo00D00000
0?l0003o0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0003o0000o`00
000000030?l000030000003o0000o`000080o`0000D000000?l0003o0000o`00000000030?l00003
0000003o0000o`000080o`0000@000000?l0003o0000o`001@00000@0?ooo`@00000_P3oool20000
00006`3oool01@000000o`000?l0003o0000000000<0o`0000<000000?l0003o00000P3o00001@00
0000o`000?l0003o0000000000<0o`0000<000000?l0003o00000P3o00001@000000o`000?l0003o
0000000000<0o`0000<000000?l0003o00000P3o000500000180oooo0P0000330?ooo`400000000K
0?ooo`050000003o0000o`000?l0000000000`3o00000`000000o`000?l000020?l000050000003o
0000o`000?l0000000000`3o00000`000000o`000?l000020?l000050000003o0000o`000?l00000
00000`3o00000`000000o`000?l000020?l000030000003oool0oooo0140oooo0`0000350?ooo`40
0000000K0?ooo`050000003o0000o`000?l0000000000`3o00000`000000o`000?l000020?l00005
0000003o0000o`000?l0000000000`3o00000`000000o`000?l000020?l000050000003o0000o`00
0?l0000000000`3o00000`000000o`000?l000020?l000030000003oool0oooo00l0oooo0P000038
0?ooo`40000000070?ooo`@000000`3oool2000000@0oooo0P0000050?ooo`050000003o0000o`00
0?l0000000000`3o00000`000000o`000?l000020?l000050000003o0000o`000?l0000000000`3o
00000`000000o`000?l000020?l000050000003o0000o`000?l0000000000`3o0006000000h0oooo
0`00003:0?ooo`40000000070?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000040?ooo`050000003o0000o`000?l0000000000`3o00000`00
0000o`000?l000020?l000050000003o0000o`000?l0000000000`3o00000`000000o`000?l00002
0?l000040000003o0000o`000?l000D000004@3oool200000<d0oooo0@00000000P0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo
00D000000?l0003o0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0003o
0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0003o0000o`000000000C
0?ooo`800000c@3oool3000000002@3oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`050000003o0000o`000?l000000000
0`3o00000`000000o`000?l000020?l000050000003o0000o`000?l0000000000`3o00000`000000
o`000?l000020?l000050000003o0000o`000?l0000000004@3oool200000=40oooo0@00000000L0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000@0oooo00D000000?l0003o0000o`00000000030?l000030000003o0000o`000080o`00
00D000000?l0003o0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0003o
0000o`000000000?0?ooo`800000d`3oool100000000203oool2000000@0oooo0P0000040?ooo`80
00001@3oool01@000000o`000?l0003o0000000000<0o`0000<000000?l0003o00000P3o00001@00
0000o`000?l0003o0000000000<0o`0000<000000?l0003o00000P3o00001@000000o`000?l0003o
0000000000d0oooo0P00003E0?ooo`400000000K0?ooo`050000003o0000o`000?l0000000000`3o
00000`000000o`000?l000020?l000050000003o0000o`000?l0000000000`3o00000`000000o`00
0?l000020?l000D000002`3oool200000=L0oooo0@00000001/0oooo00D000000?l0003o0000o`00
000000030?l000030000003o0000o`000080o`0000D000000?l0003o0000o`00000000030?l00003
0000003o0000o`000080o`0000<000000?ooo`3oool02`3oool200000=T0oooo0@00000001/0oooo
00D000000?l0003o0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0003o
0000o`00000000030?l000H00000303oool00`000000oooo0?ooo`3H0?ooo`800000000K0?ooo`05
0000003o0000o`000?l0000000000`3o00000`000000o`000?l000020?l000050000003o0000o`00
0?l0000000000`3o00000`000000oooo0?ooo`0=0?ooo`800000g03oool1000000006`3oool01@00
0000o`000?l0003o0000000000<0o`0000<000000?l0003o00000P3o00001@000000o`000?l0003o
0000000000<0o`0000<000000?ooo`3oool02`3oool200000=h0oooo0@00000001/0oooo00D00000
0?l0003o0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0003o0000o`00
000000030?l000030000003oool0oooo00X0oooo00<000000?ooo`3oool0gP3oool1000000006`3o
ool01@000000o`000?l0003o0000000000<0o`0000<000000?l0003o00000P3o00001@000000o`00
0?l0003o0000000000<0o`0000<000000?ooo`3oool0203oool200000>40oooo0@00000001/0oooo
00D000000?l0003o0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0003o
0000o`00000000030?l000030000003oool0oooo00L0oooo00<000000?ooo`3oool0h@3oool10000
00006`3oool01@000000o`000?l0003o0000000000<0o`0000<000000?l0003o00000P3o00001000
0000o`000?l0003o0005000000L0oooo0P00003S0?ooo`800000000K0?ooo`050000003o0000o`00
0?l0000000000`3o00000`000000o`000?l000020?l000050000003o0000o`000?l0000000002@3o
ool200000>H0oooo0@00000001/0oooo00D000000?l0003o0000o`00000000030?l000030000003o
0000o`000080o`0000D000000?l0003o0000o`00000000080?ooo`030000003oool0oooo0>H0oooo
0@00000001/0oooo00D000000?l0003o0000o`00000000030?l000030000003o0000o`000080o`00
00D000000?l0003o0000o`00000000060?ooo`800000j@3oool1000000006`3oool01@000000o`00
0?l0003o0000000000<0o`0000<000000?l0003o00000P3o00001@000000o`000?l0003o00000000
00D0oooo00<000000?ooo`3oool0j@3oool1000000006`3oool01@000000o`000?l0003o00000000
00<0o`0000<000000?l0003o00000P3o00001@000000o`000?l0003o0000000000@0oooo00<00000
0?ooo`3oool0jP3oool1000000006`3oool01@000000o`000?l0003o0000000000<0o`0000<00000
0?l0003o00000P3o00001@000000o`000?l0003o0000000000<0oooo00<000000?ooo`3oool0j`3o
ool1000000006`3oool01@000000o`000?l0003o0000000000<0o`0000<000000?l0003o00000P3o
00001@000000o`000?l0003o000000000080oooo00<000000?ooo`3oool0j`3oool2000000006`3o
ool01@000000o`000?l0003o0000000000<0o`0000<000000?l0003o00000P3o00001`000000o`00
0?l0003o000000000?ooo`000000k`3oool1000000006`3oool01@000000o`000?l0003o00000000
00<0o`0000<000000?l0003o00000P3o000010000000o`000?l0003o000200000?00oooo0@000000
01/0oooo00D000000?l0003o0000o`00000000030?l000030000003o0000o`000080o`001@00003a
0?ooo`40000000090?ooo`<000000P3oool2000000@0oooo0P0000050?ooo`050000003o0000o`00
0?l0000000000`3o00000`000000o`000?l000020?l000030000003oool000000?<0oooo0@000000
00X0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00D000000?l0003o0000o`00000000030?l000030000003o0000o`000080o`00
0P00003d0?ooo`40000000070?ooo`D0000000D0oooo0000003oool0oooo000000020?ooo`040000
003oool0oooo000000@0oooo00D000000?l0003o0000o`00000000030?l000030000003o0000o`00
0080o`0000<000000?ooo`3oool0l@3oool3000000001`3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool01@000000o`000?l0
003o0000000000<0o`0000@000000?l0003o0000o`000P00003e0?ooo`40000000080?ooo`030000
003oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?oo
o`050000003o0000o`000?l0000000000`3o00001P000000o`000?l000000000o`0000000?D0oooo
0@00000000T0oooo0P0000030?ooo`800000103oool2000000D0oooo00D000000?l0003o0000o`00
000000030?l000030000003o000000000080o`0000<000000?ooo`3oool0l`3oool1000000006`3o
ool01@000000o`000?l0003o0000000000<0o`000P0000030?l000030000003oool0oooo0?<0oooo
0@00000001/0oooo00D000000?l0003o0000o`00000000030?l000030000003o0000o`000080o`00
00<000000?ooo`3oool0l`3oool1000000006`3oool01@000000o`000?l0003o000000000080o`00
0P0000040?l000030000003oool0oooo0?80oooo0P00000001/0oooo00D000000?l0003o0000o`00
000000020?l000800000103o00000`000000oooo0?ooo`3c0?ooo`400000000K0?ooo`090000003o
0000o`000?l000000000o`000000003o0000000000@0o`0000<000000?ooo`3oool0l`3oool10000
00006`3oool010000000o`000?l0003o000200000080o`0000<000000?l0003o00000P3o00000`00
0000oooo0?ooo`3c0?ooo`400000000K0?ooo`050000003o0000o`000?l0000000000`3o00000`00
0000o`000?l000020?l000030000003oool0oooo0?<0oooo0@00000001/0oooo00<000000?l0003o
00000P0000030?l000030000003o0000o`000080o`0000<000000?ooo`3oool0l`3oool100000000
6`3oool01@000000o`000000003o0000000000<0o`0000<000000?l0003o00000P3o00000`000000
oooo0?ooo`3b0?ooo`800000000K0?ooo`050000003o0000o`000?l0000000000`3o000600000?D0
oooo0@00000001/0oooo00D000000?l0003o0000o`00000000030?l000030000003oool0oooo0?P0
oooo0@00000001/0oooo00D000000?l0003o0000o`00000000030?l000030000003oool0oooo0?P0
oooo0@00000001/0oooo00D000000?l0003o0000o`00000000030?l000030000003oool0oooo0?P0
oooo0@00000001/0oooo00D000000?l0003o0000o`00000000030?l000030000003oool0oooo0?P0
oooo0@00000001/0oooo00D000000?l0003o0000o`00000000030?l000030000003oool0oooo0?L0
oooo0P00000001/0oooo00D000000?l0003o0000o`00000000030?l000030000003oool0oooo0?P0
oooo0@00000001/0oooo00D000000?l0003o0000o`00000000030?l000030000003oool0oooo0?P0
oooo0@00000001/0oooo00D000000?l0003o0000o`00000000030?l000030000003oool0oooo0?P0
oooo0@00000000L0oooo0`0000040?ooo`800000103oool2000000D0oooo00D000000?l0003o0000
o`00000000030?l000030000003oool0oooo0?P0oooo0@00000000L0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00D00000
0?l0003o0000o`00000000030?l000030000003oool0oooo0?P0oooo0@00000000L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0
oooo00D000000?l0003o0000o`00000000030?l000030000003oool0oooo0?H0oooo0`00000000L0
oooo0`0000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool0
1@000000o`000?l0003o0000000000<0o`0000<000000?ooo`3oool0n03oool100000000203oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
103oool01@000000o`000?l0003o0000000000<0o`0000<000000?ooo`3oool0n03oool100000000
203oool3000000<0oooo0P0000040?ooo`8000001@3oool01@000000o`000?l0003o0000000000<0
o`0000<000000?ooo`3oool0n03oool1000000006`3oool01@000000o`000?l0003o0000000000<0
o`0000<000000?ooo`3oool0n03oool1000000006`3oool01@000000o`000?l0003o0000000000<0
o`0000<000000?ooo`3oool0n03oool1000000006`3oool01@000000o`000?l0003o0000000000<0
o`0000<000000?ooo`3oool0m`3oool2000000006`3oool01@000000o`000?l0003o0000000000<0
o`0000<000000?ooo`3oool0n03oool1000000006`3oool01@000000o`000?l0003o0000000000<0
o`0000<000000?ooo`3oool0n03oool1000000006`3oool01@000000o`000?l0003o0000000000<0
o`0000<000000?ooo`3oool0n03oool1000000006`3oool01@000000o`000?l0003o0000000000<0
o`0000<000000?ooo`3oool0n03oool1000000006`3oool01@000000o`000?l0003o0000000000<0
o`0000<000000?ooo`3oool0n03oool1000000006`3oool01@000000o`000?l0003o0000000000<0
o`0000<000000?ooo`3oool0m`3oool2000000006`3oool01@000000o`000?l0003o0000000000<0
o`0000<000000?ooo`3oool0n03oool1000000006`3oool01@000000o`000?l0003o0000000000<0
o`0000<000000?ooo`3oool0n03oool1000000006`3oool01@000000o`000?l0003o0000000000<0
o`0000<000000?ooo`3oool0n03oool1000000006`3oool01@000000o`000?l0003o0000000000<0
o`0000<000000?ooo`3oool0n03oool1000000006`3oool01@000000o`000?l0003o0000000000<0
o`0000<000000?ooo`3oool0n03oool1000000006`3oool01@000000o`000?l0003o0000000000<0
o`0000<000000?ooo`3oool0m`3oool2000000006`3oool01@000000o`000?l0003o0000000000<0
o`0000<000000?ooo`3oool0n03oool1000000006`3oool010000000o`000?l0003o000500000?X0
oooo0@00000001/0oooo00D000000?l0003o0000o`000000003n0?ooo`40000000080?ooo`800000
103oool2000000@0oooo0P0000050?ooo`050000003o0000o`000?l000000000oP3oool100000000
1`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool00000103oool01@000000o`000?l0003o000000000?h0oooo0@00000000L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0
oooo00D000000?l0003o0000o`000000003l0?ooo`<0000000080?ooo`8000000`3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00D000000?l0003o0000o`000000
003n0?ooo`40000000070?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000040?ooo`050000003o0000o`000?l000000000oP3oool10000
0000203oool2000000@0oooo0P0000040?ooo`8000001@3oool01@000000o`000?l0003o00000000
0?h0oooo0@00000001/0oooo00D000000?l0003o0000o`000000003n0?ooo`400000000K0?ooo`05
0000003o0000o`000?l000000000oP3oool1000000006`3oool01@000000o`000?l0003o00000000
0?d0oooo0P00000001/0oooo00D000000?l0003o0000o`000000003n0?ooo`400000000K0?ooo`05
0000003o0000o`000?l000000000oP3oool1000000006`3oool01@000000o`000?l0003o00000000
0?h0oooo0@00000001/0oooo00D000000?l0003o0000o`000000003n0?ooo`400000000K0?ooo`05
0000003o0000o`000?l000000000oP3oool1000000006`3oool01@000000o`000?l0003o00000000
0?d0oooo0P00000001/0oooo00D000000?l0003o0000o`000000003n0?ooo`400000000K0?ooo`05
0000003o0000o`000?l000000000oP3oool1000000006`3oool01@000000o`000?l0003o00000000
0?h0oooo0@00000001/0oooo00D000000?l0003o0000o`000000003n0?ooo`400000000K0?ooo`05
0000003o0000o`000?l000000000oP3oool1000000006`3oool01@000000o`000?l0003o00000000
0?d0oooo0P00000001/0oooo00D000000?l0003o0000o`000000003n0?ooo`400000000K0?ooo`05
0000003o0000o`000?l000000000oP3oool1000000006`3oool01@000000o`000?l0003o00000000
0?h0oooo0@00000000030?ooo`000000000000<000000P3oool2000000@0oooo0P0000040?ooo`80
00001@3oool01@000000o`000?l0003o000000000?h0oooo0@00000000<0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`020?ooo`050000003o0000o`000?l000000000oP3oool1000000000`3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00D000000?l0003o0000o`000000003l
0?ooo`<0000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool01@000000o`00
0?l0003o000000000?h0oooo0@00000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`02
0?ooo`050000003o0000o`000?l000000000oP3oool1000000000P3oool2000000@0oooo0P000004
0?ooo`800000103oool2000000D0oooo00D000000?l0003o0000o`000000003n0?ooo`400000000K
0?ooo`050000003o0000o`000?l000000000oP3oool1000000006`3oool01@000000o`000?l0003o
000000000?h0oooo0@00000001/0oooo00D000000?l0003o0000o`000000003m0?ooo`800000000K
0?ooo`050000003o0000o`000?l000000000oP3oool1000000006`3oool01@000000o`000?l0003o
000000000?h0oooo0@00000001/0oooo00D000000?l0003o0000o`000000003n0?ooo`400000000K
0?ooo`050000003o0000o`000?l000000000oP3oool1000000006`3oool01@000000o`000?l0003o
000000000?h0oooo0@00000001/0oooo00D000000?l0003o0000o`000000003m0?ooo`800000000K
0?ooo`050000003o0000o`000?l000000000oP3oool1000000006`3oool01@000000o`000?l0003o
000000000?h0oooo0@00000001/0oooo00D000000?l0003o0000o`000000003n0?ooo`400000000K
0?ooo`050000003o0000o`000?l000000000oP3oool1000000006`3oool01@000000o`000?l0003o
000000000?h0oooo0@00000001/0oooo00D000000?l0003o0000o`000000003m0?ooo`800000000K
0?ooo`050000003o0000o`000?l000000000oP3oool1000000006`3oool01@000000o`000?l0003o
000000000?h0oooo0@00000001/0oooo00D000000?l0003o0000o`000000003n0?ooo`4000000000
0`3oool0000000000003000000030?ooo`0000000000008000000`3oool2000000@0oooo0P000005
0?ooo`050000003o0000o`000?l000000000oP3oool1000000000`3oool01@000000oooo0?ooo`3o
ool0000000D0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`05
0000003o0000o`000?l000000000oP3oool1000000000`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000004
0?ooo`050000003o0000o`000?l000000000o03oool3000000000`3oool00`000000oooo0?ooo`03
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo0080oooo00D000000?l0003o0000o`000000003n0?ooo`40000000030?ooo`050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool00P3oool01@000000o`000?l0003o000000000?h0oooo0@00
00000080oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000050?ooo`050000003o0000
o`000?l000000000oP3oool1000000006`3oool01@000000o`000?l0003o000000000?h0oooo0@00
000001/0oooo00D000000?l0003o0000o`000000003n0?ooo`400000000K0?ooo`050000003o0000
o`000?l000000000o@3oool2000000006`3oool01@000000o`000?l0003o000000000?h0oooo0@00
000001/0oooo1@00003n0?ooo`400000000K0?ooo`030000003oool0oooo0?l0oooo0@3oool10000
00006`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0303oool1000000006`3ooooo000000D00000003o0?ooob00oooo003o0?ooob00oooo0000\
\>"],
  ImageRangeCache->{{{0, 286.188}, {176.5, 0}} -> {-947.089, -150.371, \
34.7726, 8.26413}}]
}, Open  ]],

Cell["\<\
Abbildung 2.19 zeigt die angepasste Dichtefunktion der Exponentialverteilung \
zusammen mit dem Histogramm der Intron-L\[ADoubleDot]ngen. Offensichtlich \
werden die beobachteten L\[ADoubleDot]ngen der Introns durch dieses Modell \
nur teilweise erkl\[ADoubleDot]rt. Es ergeben sich systematische \
Abweichungen. Aus unserer Diskussion der Verteilungen im ersten Teil des \
Kapitels wissen wir, dass diese Abweichungen (die exponentielle Verteilung \
untersch\[ADoubleDot]tzt die besonders gro\[SZ]en und kleinen \
L\[ADoubleDot]ngen und \[UDoubleDot]bersch\[ADoubleDot]tzt die \
H\[ADoubleDot]ufigkeit der mittleren L\[ADoubleDot]ngen) typisch f\
\[UDoubleDot]r Weibull- und Potenzgesetzverteilungen sind. Wir \
m\[ODoubleDot]chten aus diesem Grund hier noch die Weibull-Verteilung als ein \
weiteres Modell diskutieren. Die Weibull-Verteilung \
ber\[UDoubleDot]cksichtigt als Modell das Auftreten seltener Ereignisse und \
enth\[ADoubleDot]lt als Spezialfall die Exponentialverteilung. Auf die \
formale Sch\[ADoubleDot]tzung der Parameter f\[UDoubleDot]r eine \
Weibull-Verteilung aus einem gegebenen Datensatz wollen wir hier nicht \
eingehen, sondern f\[UDoubleDot]r vorhandene Parameter die angepasste \
Weibull-Verteilung mit dem Histogramm der Intron-L\[ADoubleDot]ngen \
vergleichen. Mit den gesch\[ADoubleDot]tzten Parametern \[Alpha] und \[Gamma] \
ist die skalierte Dichtefunktion der Weibull-Verteilung gegeben durch:\
\>", "Text",
  FontSize->13],

Cell[BoxData[{
    \(\(\[Alpha] = 1429.58;\)\), "\[IndentingNewLine]", 
    \(\(\[Gamma] = 0.7247;\)\)}], "Input"],

Cell[BoxData[
    \(\(fWeibull[x_] := 
        number*binsize*\[Gamma]\/\[Alpha]*\((x\/\[Alpha])\)\^\((\[Gamma] - 1)\
\)*\[ExponentialE]\^\(-\((x\/\[Alpha])\)\^\[Gamma]\);\)\)], "Input"],

Cell["\<\
Abbildung 2.20 zeigt die Weibull-Verteilung zusammen mit dem Histogramm der \
Intron-L\[ADoubleDot]ngen.\
\>", "Text",
  FontSize->13],

Cell[BoxData[
    \(\(plWeibull = 
        Plot[fWeibull[x], {x, min + binsize/2, max - binsize/2}, 
          DisplayFunction \[Rule] Identity];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[plIntrons, plWeibull, 
        DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.39609e-017 0.000111111 0.0147151 0.000467517 [
[.22222 -0.0125 -12 -9 ]
[.22222 -0.0125 12 0 ]
[.44444 -0.0125 -12 -9 ]
[.44444 -0.0125 12 0 ]
[.66667 -0.0125 -12 -9 ]
[.66667 -0.0125 12 0 ]
[.88889 -0.0125 -12 -9 ]
[.88889 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10822 -18 -4.5 ]
[-0.0125 .10822 0 4.5 ]
[-0.0125 .20172 -18 -4.5 ]
[-0.0125 .20172 0 4.5 ]
[-0.0125 .29523 -18 -4.5 ]
[-0.0125 .29523 0 4.5 ]
[-0.0125 .38873 -18 -4.5 ]
[-0.0125 .38873 0 4.5 ]
[-0.0125 .48223 -24 -4.5 ]
[-0.0125 .48223 0 4.5 ]
[-0.0125 .57574 -24 -4.5 ]
[-0.0125 .57574 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.22222 0 m
.22222 .00625 L
s
[(2000)] .22222 -0.0125 0 1 Mshowa
.44444 0 m
.44444 .00625 L
s
[(4000)] .44444 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(6000)] .66667 -0.0125 0 1 Mshowa
.88889 0 m
.88889 .00625 L
s
[(8000)] .88889 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.11111 0 m
.11111 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.38889 0 m
.38889 .00375 L
s
.5 0 m
.5 .00375 L
s
.55556 0 m
.55556 .00375 L
s
.61111 0 m
.61111 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.77778 0 m
.77778 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10822 m
.00625 .10822 L
s
[(200)] -0.0125 .10822 1 0 Mshowa
0 .20172 m
.00625 .20172 L
s
[(400)] -0.0125 .20172 1 0 Mshowa
0 .29523 m
.00625 .29523 L
s
[(600)] -0.0125 .29523 1 0 Mshowa
0 .38873 m
.00625 .38873 L
s
[(800)] -0.0125 .38873 1 0 Mshowa
0 .48223 m
.00625 .48223 L
s
[(1000)] -0.0125 .48223 1 0 Mshowa
0 .57574 m
.00625 .57574 L
s
[(1200)] -0.0125 .57574 1 0 Mshowa
.125 Mabswid
0 .03809 m
.00375 .03809 L
s
0 .06147 m
.00375 .06147 L
s
0 .08484 m
.00375 .08484 L
s
0 .13159 m
.00375 .13159 L
s
0 .15497 m
.00375 .15497 L
s
0 .17835 m
.00375 .17835 L
s
0 .2251 m
.00375 .2251 L
s
0 .24847 m
.00375 .24847 L
s
0 .27185 m
.00375 .27185 L
s
0 .3186 m
.00375 .3186 L
s
0 .34198 m
.00375 .34198 L
s
0 .36535 m
.00375 .36535 L
s
0 .4121 m
.00375 .4121 L
s
0 .43548 m
.00375 .43548 L
s
0 .45886 m
.00375 .45886 L
s
0 .50561 m
.00375 .50561 L
s
0 .52898 m
.00375 .52898 L
s
0 .55236 m
.00375 .55236 L
s
0 .59911 m
.00375 .59911 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.22222 .61178 m
.22222 .61803 L
s
.44444 .61178 m
.44444 .61803 L
s
.66667 .61178 m
.66667 .61803 L
s
.88889 .61178 m
.88889 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.11111 .61428 m
.11111 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.33333 .61428 m
.33333 .61803 L
s
.38889 .61428 m
.38889 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.55556 .61428 m
.55556 .61803 L
s
.61111 .61428 m
.61111 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.77778 .61428 m
.77778 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10822 m
1 .10822 L
s
.99375 .20172 m
1 .20172 L
s
.99375 .29523 m
1 .29523 L
s
.99375 .38873 m
1 .38873 L
s
.99375 .48223 m
1 .48223 L
s
.99375 .57574 m
1 .57574 L
s
.125 Mabswid
.99625 .03809 m
1 .03809 L
s
.99625 .06147 m
1 .06147 L
s
.99625 .08484 m
1 .08484 L
s
.99625 .13159 m
1 .13159 L
s
.99625 .15497 m
1 .15497 L
s
.99625 .17835 m
1 .17835 L
s
.99625 .2251 m
1 .2251 L
s
.99625 .24847 m
1 .24847 L
s
.99625 .27185 m
1 .27185 L
s
.99625 .3186 m
1 .3186 L
s
.99625 .34198 m
1 .34198 L
s
.99625 .36535 m
1 .36535 L
s
.99625 .4121 m
1 .4121 L
s
.99625 .43548 m
1 .43548 L
s
.99625 .45886 m
1 .45886 L
s
.99625 .50561 m
1 .50561 L
s
.99625 .52898 m
1 .52898 L
s
.99625 .55236 m
1 .55236 L
s
.99625 .59911 m
1 .59911 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .60332 L
.01667 .60332 L
.01667 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .60332 L
.01667 .60332 L
.01667 .01472 L
0 .01472 L
s
1 0 0 r
.01667 .01472 m
.01667 .3733 L
.03333 .3733 L
.03333 .01472 L
F
0 g
.01667 .01472 m
.01667 .3733 L
.03333 .3733 L
.03333 .01472 L
.01667 .01472 L
s
1 0 0 r
.03333 .01472 m
.03333 .25362 L
.05 .25362 L
.05 .01472 L
F
0 g
.03333 .01472 m
.03333 .25362 L
.05 .25362 L
.05 .01472 L
.03333 .01472 L
s
1 0 0 r
.05 .01472 m
.05 .19003 L
.06667 .19003 L
.06667 .01472 L
F
0 g
.05 .01472 m
.05 .19003 L
.06667 .19003 L
.06667 .01472 L
.05 .01472 L
s
1 0 0 r
.06667 .01472 m
.06667 .1545 L
.08333 .1545 L
.08333 .01472 L
F
0 g
.06667 .01472 m
.06667 .1545 L
.08333 .1545 L
.08333 .01472 L
.06667 .01472 L
s
1 0 0 r
.08333 .01472 m
.08333 .13066 L
.1 .13066 L
.1 .01472 L
F
0 g
.08333 .01472 m
.08333 .13066 L
.1 .13066 L
.1 .01472 L
.08333 .01472 L
s
1 0 0 r
.1 .01472 m
.1 .12037 L
.11667 .12037 L
.11667 .01472 L
F
0 g
.1 .01472 m
.1 .12037 L
.11667 .12037 L
.11667 .01472 L
.1 .01472 L
s
1 0 0 r
.11667 .01472 m
.11667 .10214 L
.13333 .10214 L
.13333 .01472 L
F
0 g
.11667 .01472 m
.11667 .10214 L
.13333 .10214 L
.13333 .01472 L
.11667 .01472 L
s
1 0 0 r
.13333 .01472 m
.13333 .09887 L
.15 .09887 L
.15 .01472 L
F
0 g
.13333 .01472 m
.13333 .09887 L
.15 .09887 L
.15 .01472 L
.13333 .01472 L
s
1 0 0 r
.15 .01472 m
.15 .08905 L
.16667 .08905 L
.16667 .01472 L
F
0 g
.15 .01472 m
.15 .08905 L
.16667 .08905 L
.16667 .01472 L
.15 .01472 L
s
1 0 0 r
.16667 .01472 m
.16667 .08344 L
.18333 .08344 L
.18333 .01472 L
F
0 g
.16667 .01472 m
.16667 .08344 L
.18333 .08344 L
.18333 .01472 L
.16667 .01472 L
s
1 0 0 r
.18333 .01472 m
.18333 .07315 L
.2 .07315 L
.2 .01472 L
F
0 g
.18333 .01472 m
.18333 .07315 L
.2 .07315 L
.2 .01472 L
.18333 .01472 L
s
1 0 0 r
.2 .01472 m
.2 .06941 L
.21667 .06941 L
.21667 .01472 L
F
0 g
.2 .01472 m
.2 .06941 L
.21667 .06941 L
.21667 .01472 L
.2 .01472 L
s
1 0 0 r
.21667 .01472 m
.21667 .06567 L
.23333 .06567 L
.23333 .01472 L
F
0 g
.21667 .01472 m
.21667 .06567 L
.23333 .06567 L
.23333 .01472 L
.21667 .01472 L
s
1 0 0 r
.23333 .01472 m
.23333 .06941 L
.25 .06941 L
.25 .01472 L
F
0 g
.23333 .01472 m
.23333 .06941 L
.25 .06941 L
.25 .01472 L
.23333 .01472 L
s
1 0 0 r
.25 .01472 m
.25 .05539 L
.26667 .05539 L
.26667 .01472 L
F
0 g
.25 .01472 m
.25 .05539 L
.26667 .05539 L
.26667 .01472 L
.25 .01472 L
s
1 0 0 r
.26667 .01472 m
.26667 .05258 L
.28333 .05258 L
.28333 .01472 L
F
0 g
.26667 .01472 m
.26667 .05258 L
.28333 .05258 L
.28333 .01472 L
.26667 .01472 L
s
1 0 0 r
.28333 .01472 m
.28333 .0409 L
.3 .0409 L
.3 .01472 L
F
0 g
.28333 .01472 m
.28333 .0409 L
.3 .0409 L
.3 .01472 L
.28333 .01472 L
s
1 0 0 r
.3 .01472 m
.3 .0624 L
.31667 .0624 L
.31667 .01472 L
F
0 g
.3 .01472 m
.3 .0624 L
.31667 .0624 L
.31667 .01472 L
.3 .01472 L
s
1 0 0 r
.31667 .01472 m
.31667 .04838 L
.33333 .04838 L
.33333 .01472 L
F
0 g
.31667 .01472 m
.31667 .04838 L
.33333 .04838 L
.33333 .01472 L
.31667 .01472 L
s
1 0 0 r
.33333 .01472 m
.33333 .04464 L
.35 .04464 L
.35 .01472 L
F
0 g
.33333 .01472 m
.33333 .04464 L
.35 .04464 L
.35 .01472 L
.33333 .01472 L
s
1 0 0 r
.35 .01472 m
.35 .05258 L
.36667 .05258 L
.36667 .01472 L
F
0 g
.35 .01472 m
.35 .05258 L
.36667 .05258 L
.36667 .01472 L
.35 .01472 L
s
1 0 0 r
.36667 .01472 m
.36667 .0423 L
.38333 .0423 L
.38333 .01472 L
F
0 g
.36667 .01472 m
.36667 .0423 L
.38333 .0423 L
.38333 .01472 L
.36667 .01472 L
s
1 0 0 r
.38333 .01472 m
.38333 .04417 L
.4 .04417 L
.4 .01472 L
F
0 g
.38333 .01472 m
.38333 .04417 L
.4 .04417 L
.4 .01472 L
.38333 .01472 L
s
1 0 0 r
.4 .01472 m
.4 .04183 L
.41667 .04183 L
.41667 .01472 L
F
0 g
.4 .01472 m
.4 .04183 L
.41667 .04183 L
.41667 .01472 L
.4 .01472 L
s
1 0 0 r
.41667 .01472 m
.41667 .03342 L
.43333 .03342 L
.43333 .01472 L
F
0 g
.41667 .01472 m
.41667 .03342 L
.43333 .03342 L
.43333 .01472 L
.41667 .01472 L
s
1 0 0 r
.43333 .01472 m
.43333 .03575 L
.45 .03575 L
.45 .01472 L
F
0 g
.43333 .01472 m
.43333 .03575 L
.45 .03575 L
.45 .01472 L
.43333 .01472 L
s
1 0 0 r
.45 .01472 m
.45 .03482 L
.46667 .03482 L
.46667 .01472 L
F
0 g
.45 .01472 m
.45 .03482 L
.46667 .03482 L
.46667 .01472 L
.45 .01472 L
s
1 0 0 r
.46667 .01472 m
.46667 .03061 L
.48333 .03061 L
.48333 .01472 L
F
0 g
.46667 .01472 m
.46667 .03061 L
.48333 .03061 L
.48333 .01472 L
.46667 .01472 L
s
1 0 0 r
.48333 .01472 m
.48333 .025 L
.5 .025 L
.5 .01472 L
F
0 g
.48333 .01472 m
.48333 .025 L
.5 .025 L
.5 .01472 L
.48333 .01472 L
s
1 0 0 r
.5 .01472 m
.5 .03201 L
.51667 .03201 L
.51667 .01472 L
F
0 g
.5 .01472 m
.5 .03201 L
.51667 .03201 L
.51667 .01472 L
.5 .01472 L
s
1 0 0 r
.51667 .01472 m
.51667 .025 L
.53333 .025 L
.53333 .01472 L
F
0 g
.51667 .01472 m
.51667 .025 L
.53333 .025 L
.53333 .01472 L
.51667 .01472 L
s
1 0 0 r
.53333 .01472 m
.53333 .02781 L
.55 .02781 L
.55 .01472 L
F
0 g
.53333 .01472 m
.53333 .02781 L
.55 .02781 L
.55 .01472 L
.53333 .01472 L
s
1 0 0 r
.55 .01472 m
.55 .02968 L
.56667 .02968 L
.56667 .01472 L
F
0 g
.55 .01472 m
.55 .02968 L
.56667 .02968 L
.56667 .01472 L
.55 .01472 L
s
1 0 0 r
.56667 .01472 m
.56667 .02594 L
.58333 .02594 L
.58333 .01472 L
F
0 g
.56667 .01472 m
.56667 .02594 L
.58333 .02594 L
.58333 .01472 L
.56667 .01472 L
s
1 0 0 r
.58333 .01472 m
.58333 .02594 L
.6 .02594 L
.6 .01472 L
F
0 g
.58333 .01472 m
.58333 .02594 L
.6 .02594 L
.6 .01472 L
.58333 .01472 L
s
1 0 0 r
.6 .01472 m
.6 .0236 L
.61667 .0236 L
.61667 .01472 L
F
0 g
.6 .01472 m
.6 .0236 L
.61667 .0236 L
.61667 .01472 L
.6 .01472 L
s
1 0 0 r
.61667 .01472 m
.61667 .02313 L
.63333 .02313 L
.63333 .01472 L
F
0 g
.61667 .01472 m
.61667 .02313 L
.63333 .02313 L
.63333 .01472 L
.61667 .01472 L
s
1 0 0 r
.63333 .01472 m
.63333 .02173 L
.65 .02173 L
.65 .01472 L
F
0 g
.63333 .01472 m
.63333 .02173 L
.65 .02173 L
.65 .01472 L
.63333 .01472 L
s
1 0 0 r
.65 .01472 m
.65 .0222 L
.66667 .0222 L
.66667 .01472 L
F
0 g
.65 .01472 m
.65 .0222 L
.66667 .0222 L
.66667 .01472 L
.65 .01472 L
s
1 0 0 r
.66667 .01472 m
.66667 .02313 L
.68333 .02313 L
.68333 .01472 L
F
0 g
.66667 .01472 m
.66667 .02313 L
.68333 .02313 L
.68333 .01472 L
.66667 .01472 L
s
1 0 0 r
.68333 .01472 m
.68333 .025 L
.7 .025 L
.7 .01472 L
F
0 g
.68333 .01472 m
.68333 .025 L
.7 .025 L
.7 .01472 L
.68333 .01472 L
s
1 0 0 r
.7 .01472 m
.7 .01752 L
.71667 .01752 L
.71667 .01472 L
F
0 g
.7 .01472 m
.7 .01752 L
.71667 .01752 L
.71667 .01472 L
.7 .01472 L
s
1 0 0 r
.71667 .01472 m
.71667 .01892 L
.73333 .01892 L
.73333 .01472 L
F
0 g
.71667 .01472 m
.71667 .01892 L
.73333 .01892 L
.73333 .01472 L
.71667 .01472 L
s
1 0 0 r
.73333 .01472 m
.73333 .02126 L
.75 .02126 L
.75 .01472 L
F
0 g
.73333 .01472 m
.73333 .02126 L
.75 .02126 L
.75 .01472 L
.73333 .01472 L
s
1 0 0 r
.75 .01472 m
.75 .02313 L
.76667 .02313 L
.76667 .01472 L
F
0 g
.75 .01472 m
.75 .02313 L
.76667 .02313 L
.76667 .01472 L
.75 .01472 L
s
1 0 0 r
.76667 .01472 m
.76667 .01939 L
.78333 .01939 L
.78333 .01472 L
F
0 g
.76667 .01472 m
.76667 .01939 L
.78333 .01939 L
.78333 .01472 L
.76667 .01472 L
s
1 0 0 r
.78333 .01472 m
.78333 .02033 L
.8 .02033 L
.8 .01472 L
F
0 g
.78333 .01472 m
.78333 .02033 L
.8 .02033 L
.8 .01472 L
.78333 .01472 L
s
1 0 0 r
.8 .01472 m
.8 .02079 L
.81667 .02079 L
.81667 .01472 L
F
0 g
.8 .01472 m
.8 .02079 L
.81667 .02079 L
.81667 .01472 L
.8 .01472 L
s
1 0 0 r
.81667 .01472 m
.81667 .01799 L
.83333 .01799 L
.83333 .01472 L
F
0 g
.81667 .01472 m
.81667 .01799 L
.83333 .01799 L
.83333 .01472 L
.81667 .01472 L
s
1 0 0 r
.83333 .01472 m
.83333 .01986 L
.85 .01986 L
.85 .01472 L
F
0 g
.83333 .01472 m
.83333 .01986 L
.85 .01986 L
.85 .01472 L
.83333 .01472 L
s
1 0 0 r
.85 .01472 m
.85 .01846 L
.86667 .01846 L
.86667 .01472 L
F
0 g
.85 .01472 m
.85 .01846 L
.86667 .01846 L
.86667 .01472 L
.85 .01472 L
s
1 0 0 r
.86667 .01472 m
.86667 .01799 L
.88333 .01799 L
.88333 .01472 L
F
0 g
.86667 .01472 m
.86667 .01799 L
.88333 .01799 L
.88333 .01472 L
.86667 .01472 L
s
1 0 0 r
.88333 .01472 m
.88333 .01752 L
.9 .01752 L
.9 .01472 L
F
0 g
.88333 .01472 m
.88333 .01752 L
.9 .01752 L
.9 .01472 L
.88333 .01472 L
s
1 0 0 r
.9 .01472 m
.9 .01659 L
.91667 .01659 L
.91667 .01472 L
F
0 g
.9 .01472 m
.9 .01659 L
.91667 .01659 L
.91667 .01472 L
.9 .01472 L
s
1 0 0 r
.91667 .01472 m
.91667 .01892 L
.93333 .01892 L
.93333 .01472 L
F
0 g
.91667 .01472 m
.91667 .01892 L
.93333 .01892 L
.93333 .01472 L
.91667 .01472 L
s
1 0 0 r
.93333 .01472 m
.93333 .01612 L
.95 .01612 L
.95 .01472 L
F
0 g
.93333 .01472 m
.93333 .01612 L
.95 .01612 L
.95 .01472 L
.93333 .01472 L
s
1 0 0 r
.95 .01472 m
.95 .01705 L
.96667 .01705 L
.96667 .01472 L
F
0 g
.95 .01472 m
.95 .01705 L
.96667 .01705 L
.96667 .01472 L
.95 .01472 L
s
1 0 0 r
.96667 .01472 m
.96667 .01846 L
.98333 .01846 L
.98333 .01472 L
F
0 g
.96667 .01472 m
.96667 .01846 L
.98333 .01846 L
.98333 .01472 L
.96667 .01472 L
s
1 0 0 r
.98333 .01472 m
.98333 .01799 L
1 .01799 L
1 .01472 L
F
0 g
.98333 .01472 m
.98333 .01799 L
1 .01799 L
1 .01472 L
.98333 .01472 L
s
.00833 .46566 m
.01065 .42662 L
.01313 .39467 L
.0176 .35188 L
.02292 .31512 L
.02775 .28945 L
.03828 .24822 L
.04822 .22005 L
.05907 .19635 L
.06908 .17877 L
.09173 .14866 L
.11106 .12971 L
.13236 .11341 L
.15408 .10019 L
.17396 .09027 L
.21399 .07475 L
.25499 .06307 L
.29442 .05453 L
.33639 .04746 L
.37679 .0421 L
.41972 .03755 L
.46109 .03401 L
.50089 .03121 L
.54323 .02875 L
.584 .02678 L
.62321 .02519 L
.66494 .02375 L
.70512 .02258 L
.74782 .02152 L
.78896 .02066 L
.82854 .01994 L
.87065 .01928 L
.91119 .01873 L
.95017 .01828 L
.99167 .01785 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00B@3oool4000000<0oooo0P0000040?ooo`800000
103oool2000002L0oooo0`0000020?ooo`800000103oool2000000@0oooo0P00000U0?ooo`<00000
103oool2000000@0oooo0P0000040?ooo`8000009P3oool2000000@0oooo0P0000040?ooo`800000
103oool2000001@0oooo00190?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002L0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool08P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000T0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000001<0oooo001:0?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002@0oooo
1@0000001@3oool000000?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`00000T0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002@0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000004`3oool004/0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0R
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000002@0oooo0`0000030?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000U0?ooo`800000
0`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000004`3oool004T0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000009@3oool00`000000
oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`00000U0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002@0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000004`3oool004X0oooo0P0000040?ooo`800000103oool2000000@0oooo
0P00000W0?ooo`8000000`3oool2000000@0oooo0P0000040?ooo`8000009P3oool3000000<0oooo
0P0000040?ooo`800000103oool2000002H0oooo0P0000040?ooo`800000103oool2000000@0oooo
0P00000D0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`006`3ooooo000000D000000@3oool001/0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo0@0000010?ooo`00503oool20000
00D0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0I0?ooo`4000000@3oool001<0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3o0?ooo`40oooo0@0000010?oo
o`004`3oool010000000oooo0?ooo`0000040?ooool000001@0000010?ooo`004`3oool010000000
oooo0?ooo`0000040?ooo`050000003o0000o`000?l0000000000`3o00000`000000o`000?l00002
0?l000050000003o0000o`000?l0000000000`3o00000`000000o`000?l000020?l000050000003o
0000o`000?l0000000000`3o00000`000000o`000?l000020?l000050000003o0000o`000?l00000
00000`3o00000`000000o`000?l000020?l000050000003o0000o`000?l0000000000`3o00000`00
0000o`000?l000020?l000050000003o0000o`000?l0000000000`3o00000`000000o`000?l00002
0?l000050000003o0000o`000?l0000000000`3o00000`000000o`000?l000020?l000050000003o
0000o`000?l0000000000`3o00000`000000o`000?l000020?l000050000003o0000o`000?l00000
00000`3o00000`000000o`000?l000020?l000050000003o0000o`000?l0000000000`3o00000`00
0000o`000?l000020?l000050000003o0000o`000?l0000000000`3o00000`000000o`000?l00002
0?l000050000003o0000o`000?l0000000000`3o00000`000000o`000?l000020?l000050000003o
0000o`000?l0000000000`3o00000`000000o`000?l000020?l000050000003o0000o`000?l00000
00000`3o00001@000000o`000?l0003o0000000000@0oooo2@0000040?l003d000000@3oool001<0
oooo00@000000?ooo`3oool00000103oool01@000000o`000?l0003o0000000000<0o`0000<00000
0?l0003o00000P3o00001@000000o`000?l0003o0000000000<0o`0000<000000?l0003o00000P3o
00001@000000o`000?l0003o0000000000<0o`0000<000000?l0003o00000P3o00001@000000o`00
0?l0003o0000000000<0o`0000<000000?l0003o00000P3o00001@000000o`000?l0003o00000000
00<0o`0000<000000?l0003o00000P3o00001@000000o`000?l0003o0000000000<0o`0000<00000
0?l0003o00000P3o00001@000000o`000?l0003o0000000000<0o`0000<000000?l0003o00000P3o
00001@000000o`000?l0003o0000000000<0o`0000<000000?l0003o00000P3o00001@000000o`00
0?l0003o0000000000<0o`0000<000000?l0003o00000P3o00001@000000o`000?l0003o00000000
00<0o`001P0000030?l000D00000103o00001@000000o`000?l0003o0000000000<0o`0000<00000
0?l0003o00000P3o000/000003/0oooo0@0000010?ooo`00503oool2000000D0oooo00D000000?l0
003o0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0003o0000o`000000
00030?l000030000003o0000o`000080o`0000D000000?l0003o0000o`00000000030?l000030000
003o0000o`000080o`0000D000000?l0003o0000o`00000000030?l000030000003o0000o`000080
o`0000D000000?l0003o0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0
003o0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0003o0000o`000000
00030?l000030000003o0000o`000080o`0000D000000?l0003o0000o`00000000030?l000030000
003o0000o`000080o`0000D000000?l0003o0000o`00000000030?l000030000003o0000o`000080
o`0000D000000?l0003o0000o`00000000030?l000030000003oool0oooo0080oooo00H000000?l0
003o0000o`000000003ooolE000006H0oooo0@0000010?ooo`006`3oool01@000000o`000?l0003o
0000000000<0o`0000<000000?l0003o00000P3o00001@000000o`000?l0003o0000000000<0o`00
00<000000?l0003o00000P3o00001@000000o`000?l0003o0000000000<0o`0000<000000?l0003o
00000P3o00001@000000o`000?l0003o0000000000<0o`0000<000000?l0003o00000P3o00001@00
0000o`000?l0003o0000000000<0o`0000<000000?l0003o00000P3o00001@000000o`000?l0003o
0000000000<0o`0000<000000?l0003o00000P3o00001@000000o`000?l0003o0000000000<0o`00
00<000000?l0003o00000P3o00001@000000o`000?l0003o0000000000<0o`0000<000000?l0003o
00000P3o00001@000000o`000?l0003o0000000000<0o`0000<000000?l0003o00000P3o00001000
0000o`000?l0003o000?000000L0oooo1@00001_0?ooo`4000000@3oool001/0oooo00D000000?l0
003o0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0003o0000o`000000
00030?l000030000003o0000o`000080o`0000D000000?l0003o0000o`00000000030?l000030000
003o0000o`000080o`0000D000000?l0003o0000o`00000000030?l000030000003o0000o`000080
o`0000D000000?l0003o0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0
003o0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0003o0000o`000000
00030?l000030000003o0000o`000080o`0000D000000?l0003o0000o`00000000030?l000030000
003o0000o`000080o`0000@000000?l0003o0000o`004@0000260?ooo`4000000@3oool001/0oooo
00D000000?l0003o0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0003o
0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0003o0000o`0000000003
0?l000030000003o0000o`000080o`0000D000000?l0003o0000o`00000000030?l000030000003o
0000o`000080o`0000D000000?l0003o0000o`00000000030?l000030000003o0000o`000080o`00
00D000000?l0003o0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0003o
0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0003o0000o`0000000003
0?l000030000003o0000o`000080o`002`00002?0?ooo`8000000@3oool001/0oooo00D000000?l0
003o0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0003o0000o`000000
00030?l000030000003o0000o`000080o`0000D000000?l0003o0000o`00000000030?l000030000
003o0000o`000080o`0000D000000?l0003o0000o`00000000030?l000030000003o0000o`000080
o`0000D000000?l0003o0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0
003o0000o`00000000030?l000H000000`3o00001@000000o`000?l0003o0000000000@0o`0000<0
00000?l0000000003`00002F0?ooo`4000000@3oool001/0oooo00D000000?l0003o0000o`000000
00030?l000030000003o0000o`000080o`0000D000000?l0003o0000o`00000000030?l000030000
003o0000o`000080o`0000D000000?l0003o0000o`00000000030?l000030000003o0000o`000080
o`0000D000000?l0003o0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0
003o0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0003o0000o`000000
00030?l000030000003oool0oooo0080oooo00@000000?l0003o0000o`002`0000020?l000030000
003oool0oooo0:40oooo0@0000010?ooo`006`3oool01@000000o`000?l0003o0000000000<0o`00
00<000000?l0003o00000P3o00001@000000o`000?l0003o0000000000<0o`0000<000000?l0003o
00000P3o00001@000000o`000?l0003o0000000000<0o`0000<000000?l0003o00000P3o00001@00
0000o`000?l0003o0000000000<0o`0000<000000?l0003o00000P3o00001@000000o`000?l0003o
0000000000<0o`0000<000000?l0003o00000P3o00001@000000o`000?l0003o0000000000<0o`00
00<000000?ooo`3oool00P3oool7000000H0oooo00D000000?l0003o0000o`000000002S0?ooo`40
00000@3oool001/0oooo00D000000?l0003o0000o`00000000030?l000030000003o0000o`000080
o`0000D000000?l0003o0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0
003o0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0003o0000o`000000
00030?l000030000003o0000o`000080o`0000D000000?l0003o0000o`00000000030?l000030000
003o0000o`000080o`003P0000030?l000030000003oool0oooo00H0oooo1@00002S0?ooo`400000
0@3oool001/0oooo00D000000?l0003o0000o`00000000030?l000030000003o0000o`000080o`00
00D000000?l0003o0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0003o
0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0003o0000o`0000000003
0?l000030000003o0000o`000080o`0000D000000?l0003o0000o`00000000030?l000030000003o
0000o`000080o`0000@000000?ooo`3oool0oooo1@0000040?ooo`050000003o0000o`000?l00000
0000/03oool100000040oooo000K0?ooo`050000003o0000o`000?l0000000000`3o00000`000000
o`000?l000020?l000050000003o0000o`000?l0000000000`3o00000`000000o`000?l000020?l0
00050000003o0000o`000?l0000000000`3o00000`000000o`000?l000020?l000050000003o0000
o`000?l0000000000`3o00000`000000o`000?l000020?l000050000003o0000o`000?l000000000
0`3o00000`000000o`000?l000020?l000@000002@3oool500000:l0oooo0P0000010?ooo`006`3o
ool01@000000o`000?l0003o0000000000<0o`0000<000000?l0003o00000P3o00001@000000o`00
0?l0003o0000000000<0o`0000<000000?l0003o00000P3o00001@000000o`000?l0003o00000000
00<0o`0000<000000?l0003o00000P3o00001@000000o`000?l0003o0000000000<0o`0000<00000
0?l0003o00000P3o000010000000o`000?l0003o000:00000<40oooo0@0000010?ooo`006`3oool0
1@000000o`000?l0003o0000000000<0o`0000<000000?l0003o00000P3o00001@000000o`000?l0
003o0000000000<0o`0000<000000?l0003o00000P3o00001@000000o`000?l0003o0000000000<0
o`0000<000000?l0003o00000P3o00001@000000o`000?l0003o0000000000<0o`0000<000000?l0
003o00000P3o000>00000<40oooo0@0000010?ooo`006`3oool01@000000o`000?l0003o00000000
00<0o`0000<000000?l0003o00000P3o00001@000000o`000?l0003o0000000000<0o`0000<00000
0?l0003o00000P3o00001@000000o`000?l0003o0000000000<0o`0000<000000?l0003o00000P3o
00001@000000o`000?l0003o0000000000<0o`001P000000103oool0000000000000003:0?ooo`40
00000@3oool001/0oooo00D000000?l0003o0000o`00000000030?l000030000003o0000o`000080
o`0000D000000?l0003o0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0
003o0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0003o0000o`000000
00030?l000030000003oool0oooo0080oooo0P00003=0?ooo`4000000@3oool001/0oooo00D00000
0?l0003o0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0003o0000o`00
000000030?l000030000003o0000o`000080o`0000D000000?l0003o0000o`00000000030?l00003
0000003o0000o`000080o`0000D000000?l0003o0000o`00000000030?l000030000003oool00000
00800000c`3oool100000040oooo000K0?ooo`050000003o0000o`000?l0000000000`3o00000`00
0000o`000?l000020?l000050000003o0000o`000?l0000000000`3o00000`000000o`000?l00002
0?l000050000003o0000o`000?l0000000000`3o00000`000000o`000?l000020?l000040000003o
0000o`000?l000H00000d@3oool200000040oooo000K0?ooo`050000003o0000o`000?l000000000
0`3o00000`000000o`000?l000020?l000050000003o0000o`000?l0000000000`3o00000`000000
o`000?l000020?l000050000003o0000o`000?l0000000000`3o00000`000000o`000?l000020?l0
00D0000000<0oooo000000000000e03oool100000040oooo000K0?ooo`050000003o0000o`000?l0
000000000`3o00000`000000o`000?l000020?l000050000003o0000o`000?l0000000000`3o0000
0`000000o`000?l000020?l000050000003o0000o`000?l0000000000`3o00000`000000o`000?l0
00020?l000040000003oool0oooo0?ooo`800000eP3oool100000040oooo000K0?ooo`050000003o
0000o`000?l0000000000`3o00000`000000o`000?l000020?l000050000003o0000o`000?l00000
00000`3o00000`000000o`000?l000020?l000050000003o0000o`000?l0000000000`3o00000`00
0000o`000?l000020?l000040000003oool0000000000=P0oooo0@0000010?ooo`001`3oool40000
00<0oooo0P0000040?ooo`8000001@3oool01@000000o`000?l0003o0000000000<0o`0000<00000
0?l0003o00000P3o00001@000000o`000?l0003o0000000000<0o`0000<000000?l0003o00000P3o
000010000000o`000?l0003o000;00000=X0oooo0@0000010?ooo`001`3oool00`000000oooo0?oo
o`030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool01@000000
o`000?l0003o0000000000<0o`0000<000000?l0003o00000P3o00001@000000o`000?l0003o0000
000000<0o`0000<000000?l0003o00000P3o00001@000000o`000?l0003o0000000000L0oooo0P00
003K0?ooo`4000000@3oool000P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000@0oooo00D000000?l0003o0000o`00000000030?l00003
0000003o0000o`000080o`0000D000000?l0003o0000o`00000000030?l000030000003o0000o`00
0080o`0000D000000?l0003o0000o`00000000050?ooo`800000g03oool200000040oooo00090?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00D000000?l0003o0000o`00000000030?l000030000003o0000o`000080o`00
00D000000?l0003o0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0003o
0000o`00000000030?ooo`800000g`3oool100000040oooo00070?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`050000003o
0000o`000?l0000000000`3o00000`000000o`000?l000020?l000050000003o0000o`000?l00000
00000`3o00000`000000o`000?l000020?l000050000003o0000o`000?l0000000000P3oool00`00
0000oooo0?ooo`3O0?ooo`4000000@3oool000P0oooo0P0000040?ooo`800000103oool2000000D0
oooo00D000000?l0003o0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0
003o0000o`00000000030?l000030000003o0000o`000080o`001@0000000`3oool000000?ooo`3Q
0?ooo`4000000@3oool001/0oooo00D000000?l0003o0000o`00000000030?l000030000003o0000
o`000080o`0000D000000?l0003o0000o`00000000030?l000030000003o0000o`000080o`0000<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`3Q0?ooo`4000000@3oool001/0oooo00D00000
0?l0003o0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0003o0000o`00
000000030?l000030000003o0000o`000080o`0000D000000?ooo`3oool0oooo0000003T0?ooo`40
00000@3oool001/0oooo00D000000?l0003o0000o`00000000030?l000030000003o0000o`000080
o`0000D000000?l0003o0000o`00000000030?l000H000000P3oool00`000000oooo0?ooo`3R0?oo
o`8000000@3oool001/0oooo00D000000?l0003o0000o`00000000030?l000030000003o0000o`00
0080o`0000D000000?l0003o0000o`00000000030?l000030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0i03oool100000040oooo000K0?ooo`050000003o0000o`000?l0000000000`3o0000
0`000000o`000?l000020?l000050000003o0000o`000?l0000000000`3o00000`000000oooo0?oo
o`030?ooo`030000003oool0oooo0>D0oooo0@0000010?ooo`006`3oool01@000000o`000?l0003o
0000000000<0o`0000<000000?l0003o00000P3o00001@000000o`000?l0003o0000000000<0o`00
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3V0?ooo`4000000@3oool001/0oooo00D0
00000?l0003o0000o`00000000030?l000030000003o0000o`000080o`0000D000000?l0003o0000
o`00000000030?l000050000003oool0oooo0?ooo`000000j@3oool100000040oooo000K0?ooo`05
0000003o0000o`000?l0000000000`3o00000`000000o`000?l000020?l000050000003o0000o`00
0?l0000000000`3o000010000000oooo0?ooo`00003Z0?ooo`4000000@3oool001/0oooo00D00000
0?l0003o0000o`00000000030?l000030000003o0000o`000080o`0000@000000?l0003o0000o`00
1@0000000`3oool000000?ooo`3Y0?ooo`8000000@3oool001/0oooo00D000000?l0003o0000o`00
000000030?l000030000003o0000o`000080o`0000D000000?l0003o0000o`00000000040?ooo`03
0000003oool0oooo0>X0oooo0@0000010?ooo`006`3oool01@000000o`000?l0003o0000000000<0
o`0000<000000?l0003o00000P3o00001@000000o`000?l0003o0000000000<0oooo00<000000?oo
o`3oool0j`3oool100000040oooo000K0?ooo`050000003o0000o`000?l0000000000`3o00000`00
0000o`000?l000020?l000050000003o0000o`000?l0000000000`3oool00`000000oooo0?ooo`3[
0?ooo`4000000@3oool001/0oooo00D000000?l0003o0000o`00000000030?l000030000003o0000
o`000080o`0000D000000?l0003o0000o`00000000020?ooo`030000003oool0oooo0>`0oooo0@00
00010?ooo`006`3oool01@000000o`000?l0003o0000000000<0o`0000<000000?l0003o00000P3o
00001`000000o`000?l0003o000000000?ooo`000000k`3oool100000040oooo000K0?ooo`050000
003o0000o`000?l0000000000`3o00000`000000o`000?l000020?l000040000003o0000o`000?l0
00800000k`3oool200000040oooo000K0?ooo`050000003o0000o`000?l0000000000`3o00000`00
0000o`000?l000020?l000050000003o0000o`000?l000000000l@3oool100000040oooo000K0?oo
o`050000003o0000o`000?l0000000000`3o00000`000000o`000?l000020?l000050000003o0000
o`000?l000000000l@3oool100000040oooo000K0?ooo`050000003o0000o`000?l0000000000`3o
00000`000000o`000?l000020?l000D00000l@3oool100000040oooo00090?ooo`<000000P3oool2
000000@0oooo0P0000050?ooo`050000003o0000o`000?l0000000000`3o00000`000000o`000?l0
00020?l000040000003oool0oooo00000?80oooo0@0000010?ooo`002P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool01@000000
o`000?l0003o0000000000<0o`0000<000000?l0003o00000P3o00000`000000oooo0000003c0?oo
o`4000000@3oool000L0oooo1@0000001@3oool000000?ooo`3oool000000080oooo00@000000?oo
o`3oool00000103oool01@000000o`000?l0003o0000000000<0o`0000<000000?l0003o00000P3o
000200000?<0oooo0P0000010?ooo`001`3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000103oool01@000000o`000?l0003o00000000
00<0o`0000<000000?l0003o00000P3o000200000?@0oooo0@0000010?ooo`00203oool00`000000
oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool0
1@000000o`000?l0003o0000000000<0o`0000<000000?l0003o00000P3o00000`000000oooo0?oo
o`3c0?ooo`4000000@3oool000T0oooo0P0000030?ooo`800000103oool2000000D0oooo00D00000
0?l0003o0000o`00000000030?l000030000003o0000o`000080o`0000<000000?ooo`3oool0l`3o
ool100000040oooo000K0?ooo`050000003o0000o`000?l0000000000`3o000010000000o`000?l0
003o000200000?D0oooo0@0000010?ooo`006`3oool01@000000o`000?l0003o0000000000<0o`00
00@000000?l0003o0000o`000P00003e0?ooo`4000000@3oool001/0oooo00D000000?l0003o0000
o`00000000030?l000040000003o0000o`000?l000800000m03oool200000040oooo000K0?ooo`05
0000003o0000o`000?l0000000000`3o00001P000000o`000?l000000000o`0000000?D0oooo0@00
00010?ooo`006`3oool01@000000o`000?l0003o0000000000<0o`0000H000000?l0003o00000000
0?l00000003e0?ooo`4000000@3oool001/0oooo00D000000?l0003o0000o`00000000030?l00006
0000003o0000o`000000003o00000000m@3oool100000040oooo000K0?ooo`050000003o0000o`00
0?l0000000000`3o00001P000000o`000?l000000000o`0000000?D0oooo0@0000010?ooo`006`3o
ool01@000000o`000?l0003o0000000000<0o`0000<000000?l0000000000P3o00000`000000oooo
0?ooo`3c0?ooo`4000000@3oool001/0oooo00D000000?l0003o0000o`00000000030?l000030000
003o000000000080o`0000<000000?ooo`3oool0lP3oool200000040oooo000K0?ooo`050000003o
0000o`000?l0000000000`3o00000`000000o`00000000020?l000030000003oool0oooo0?<0oooo
0@0000010?ooo`006`3oool01@000000o`000?l0003o0000000000<0o`001P00003e0?ooo`400000
0@3oool001/0oooo00D000000?l0003o0000o`00000000030?l000800000n@3oool100000040oooo
000K0?ooo`050000003o0000o`000?l0000000000`3o000200000?T0oooo0@0000010?ooo`006`3o
ool01@000000o`000?l0003o0000000000<0o`000P00003i0?ooo`4000000@3oool001/0oooo00D0
00000?l0003o0000o`00000000030?l000030000003oool0oooo0?P0oooo0@0000010?ooo`006`3o
ool01@000000o`000?l0003o0000000000<0o`0000<000000?ooo`3oool0m`3oool200000040oooo
000K0?ooo`050000003o0000o`000?l0000000000`3o00000`000000oooo0?ooo`3h0?ooo`400000
0@3oool001/0oooo00D000000?l0003o0000o`00000000030?l000030000003oool0oooo0?P0oooo
0@0000010?ooo`006`3oool01@000000o`000?l0003o000000000080o`000P00003j0?ooo`400000
0@3oool000L0oooo0`0000040?ooo`800000103oool2000000D0oooo00D000000?l0003o0000o`00
000000020?l000800000nP3oool100000040oooo00070?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`050000003o0000o`00
0?l0000000000P3o000200000?X0oooo0@0000010?ooo`001`3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool01@000000o`00
0?l0003o000000000080o`000P00003i0?ooo`8000000@3oool000L0oooo0`0000030?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool01@000000o`000?l0003o0000
00000080o`000P00003j0?ooo`4000000@3oool000P0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00T000000?l0003o0000o`00
0000003o000000000?l000000000nP3oool100000040oooo00080?ooo`<000000`3oool2000000@0
oooo0P0000050?ooo`090000003o0000o`000?l000000000o`000000003o000000000?X0oooo0@00
00010?ooo`006`3oool02@000000o`000?l0003o000000000?l000000000o`000000003j0?ooo`40
00000@3oool001/0oooo00T000000?l0003o0000o`000000003o000000000?l000000000nP3oool1
00000040oooo000K0?ooo`090000003o0000o`000?l000000000o`000000003o000000000?T0oooo
0P0000010?ooo`006`3oool02@000000o`000?l0003o000000000?l000000000o`000000003j0?oo
o`4000000@3oool001/0oooo00@000000?l0003o0000o`000P0000020?l000030000003oool0oooo
0?P0oooo0@0000010?ooo`006`3oool010000000o`000?l0003o000200000080o`0000<000000?oo
o`3oool0n03oool100000040oooo000K0?ooo`040000003o0000o`000?l0008000000P3o00000`00
0000oooo0?ooo`3h0?ooo`4000000@3oool001/0oooo00@000000?l0003o0000o`000P0000020?l0
00030000003oool0oooo0?P0oooo0@0000010?ooo`006`3oool01@000000o`000?l0003o00000000
00<0o`0000<000000?ooo`3oool0m`3oool200000040oooo000K0?ooo`050000003o0000o`000?l0
000000000`3o00000`000000oooo0?ooo`3h0?ooo`4000000@3oool001/0oooo00D000000?l0003o
0000o`00000000030?l000030000003oool0oooo0?P0oooo0@0000010?ooo`006`3oool01@000000
o`000?l0003o0000000000<0o`0000<000000?ooo`3oool0n03oool100000040oooo000K0?ooo`05
0000003o0000o`000?l0000000000`3o00000`000000oooo0?ooo`3h0?ooo`4000000@3oool001/0
oooo00D000000?l0003o0000o`00000000030?l000030000003oool0oooo0?P0oooo0@0000010?oo
o`006`3oool01@000000o`000?l0003o0000000000<0o`0000<000000?ooo`3oool0m`3oool20000
0040oooo000K0?ooo`050000003o0000o`000?l0000000000`3o00000`000000oooo0?ooo`3h0?oo
o`4000000@3oool001/0oooo00<000000?l0003o00001P00003j0?ooo`4000000@3oool001/0oooo
00<000000?l0003o00000P00003n0?ooo`4000000@3oool000P0oooo0P0000040?ooo`800000103o
ool2000000D0oooo00<000000?l0003o00000P00003n0?ooo`4000000@3oool000L0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0
oooo00<000000?l0003o00000P00003n0?ooo`4000000@3oool000L0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<00000
0?l0003o00000P00003m0?ooo`8000000@3oool000P0oooo0P0000030?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool00000103oool00`000000o`000?l0000200000?h0oooo0@00
00010?ooo`001`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000103oool00`000000o`000?l0000200000?h0oooo0@0000010?ooo`00
203oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000o`000?l0000200000?h0oooo
0@0000010?ooo`006`3oool00`000000o`000?l0000200000?h0oooo0@0000010?ooo`006`3oool0
0`000000o`000?l0000200000?h0oooo0@0000010?ooo`006`3oool00`000000o`000?l000020000
0?d0oooo0P0000010?ooo`006`3oool00`000000o`000?l0000200000?h0oooo0@0000010?ooo`00
6`3oool00`000000o`000?l0000200000?h0oooo0@0000010?ooo`006`3oool00`000000o`000?l0
000200000?h0oooo0@0000010?ooo`006`3oool00`000000o`000?l0000200000?h0oooo0@000001
0?ooo`006`3oool00`000000o`000?l0000200000?h0oooo0@0000010?ooo`006`3oool00`000000
o`000?l0000200000?d0oooo0P0000010?ooo`006`3oool00`000000o`000?l0000200000?h0oooo
0@0000010?ooo`006`3oool00`000000o`000?l0000200000?h0oooo0@0000010?ooo`006`3oool0
1@000000o`000000003o000000000?h0oooo0@0000010?ooo`006`3oool01@000000o`000000003o
000000000?h0oooo0@0000010?ooo`006`3oool01@000000o`000000003o000000000?h0oooo0@00
00010?ooo`006`3oool01@000000o`000000003o000000000?d0oooo0P0000010?ooo`006`3oool0
1@000000o`000000003o000000000?h0oooo0@0000010?ooo`006`3oool01@000000o`000000003o
000000000?h0oooo0@0000010?ooo`006`3oool01@000000o`000?l0003o000000000?h0oooo0@00
00010?ooo`0000<0oooo0000000000000`0000020?ooo`800000103oool2000000@0oooo0P000005
0?ooo`050000003o0000o`000?l000000000oP3oool100000040oooo00030?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool00P3oool01@000000o`000?l0003o000000000?h0oooo0@0000010?oo
o`000`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00D000000?l0003o0000o`00
0000003m0?ooo`8000000@3oool000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?oo
o`050000003o0000o`000?l000000000oP3oool100000040oooo00030?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool00P3oool01@000000o`000?l0003o000000000?h0oooo0@0000010?ooo`00
0P3oool2000000@0oooo0P0000040?ooo`800000103oool2000000D0oooo00D000000?l0003o0000
o`000000003n0?ooo`4000000@3oool001/0oooo00D000000?l0003o0000o`000000003n0?ooo`40
00000@3oool001/0oooo00D000000?l0003o0000o`000000003n0?ooo`4000000@3oool001/0oooo
00D000000?l0003o0000o`000000003m0?ooo`8000000@3oool001/0oooo00D000000?l0003o0000
o`000000003n0?ooo`4000000@3oool001/0oooo00D000000?l0003o0000o`000000003n0?ooo`40
00000@3oool001/0oooo00D000000?l0003o0000o`000000003n0?ooo`4000000@3oool001/0oooo
00D000000?l0003o0000o`000000003n0?ooo`4000000@3oool001/0oooo00D000000?l0003o0000
o`000000003n0?ooo`4000000@3oool001/0oooo00D000000?l0003o0000o`000000003m0?ooo`80
00000@3oool001/0oooo00D000000?l0003o0000o`000000003n0?ooo`4000000@3oool001/0oooo
00D000000?l0003o0000o`000000003n0?ooo`4000000@3oool001/0oooo00D000000?l0003o0000
o`000000003n0?ooo`4000000@3oool001/0oooo00D000000?l0003o0000o`000000003n0?ooo`40
00000@3oool001/0oooo00D000000?l0003o0000o`000000003n0?ooo`4000000@3oool001/0oooo
00D000000?l0003o0000o`000000003m0?ooo`8000000@3oool001/0oooo00D000000?l0003o0000
o`000000003n0?ooo`4000000@3oool001/0oooo00D000000?l0003o0000o`000000003n0?ooo`40
00000@3oool001/0oooo00D000000?l0003o0000o`000000003n0?ooo`4000000@3oool000030?oo
o`000000000000<0000000<0oooo0000000000000P0000030?ooo`800000103oool2000000D0oooo
00D000000?l0003o0000o`000000003n0?ooo`4000000@3oool000<0oooo00D000000?ooo`3oool0
oooo000000050?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool0
1@000000o`000?l0003o000000000?h0oooo0@0000010?ooo`000`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000040?ooo`050000003o0000o`000?l000000000o@3oool200000040oooo00030?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool00P3oool01@000000o`000?l0003o000000000?h0oooo0@000001
0?ooo`000`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00D000000?l0003o0000
o`000000003n0?ooo`4000000@3oool00080oooo0P0000040?ooo`800000103oool2000000@0oooo
0P0000050?ooo`050000003o0000o`000?l000000000oP3oool100000040oooo000K0?ooo`050000
003o0000o`000?l000000000oP3oool100000040oooo000K0?ooo`050000003o0000o`000?l00000
0000oP3oool100000040oooo000K0?ooo`050000003o0000o`000?l000000000o@3oool200000040
oooo000K0?ooo`050000003o0000o`000?l000000000oP3oool100000040oooo000K0?ooo`D00000
oP3oool100000040oooo000K0?ooo`030000003oool0oooo0?l0oooo0@3oool100000040oooo000K
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;
0?ooo`4000000@3oool001/0ooooo`00000500000040oooo003o0?ooob40oooo003o0?ooob40oooo
0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-944.509, -149.804, 34.6651, \
8.23859}}]
}, Open  ]],

Cell[TextData[{
  "Wie man deutlich sieht",
  Cell[BoxData[
      \(TraditionalForm\`\(, \^19\)\)]],
  " beschreibt die Weibull-Verteilung die beobachteten Daten besser als die \
Exponentialverteilung. Ein mathematisches Modell der Genomevolution, das die \
Entstehung und zeitliche Entwicklung von Introns zu beschreiben versucht, m\
\[UDoubleDot]sste also Mechanismen der Sequenzmodifikation finden, die eine \
solche systematische Abweichung der L\[ADoubleDot]ngenverteilung von einem \
exponentiellen Verlauf erkl\[ADoubleDot]ren k\[ODoubleDot]nnen."
}], "Text",
  FontSize->13],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\^14\)]],
  " http://genome.ucsc.edu/ unter der Rubrik Tables.\n\n",
  Cell[BoxData[
      \(TraditionalForm\`\^15\)]],
  " Auch der erste Eintrag, der aus der Tabellen\[UDoubleDot]berschrift \
stammt, n\[ADoubleDot]mlich ",
  StyleBox["{exonStarts#1, exonEnds}",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " wird in diesem Schritt auf die leere Menge abgebildet.\n\n",
  Cell[BoxData[
      \(TraditionalForm\`\^16\)]],
  " Eine Besonderheit des Genom Browsers ist seine Z\[ADoubleDot]hlweise, n\
\[ADoubleDot]mlich an der Position Null orientiert (0-basiert) bei den \
Startpositionen und 1-basiert bei den Endpositionen. Daher ergeben sich die L\
\[ADoubleDot]ngen als Differenz minus 2 (statt Differenz minus 1).\n\n",
  Cell[BoxData[
      \(TraditionalForm\`\^17\)]],
  " Dies l\[ADoubleDot]sst sich damit begr\[UDoubleDot]nden, dass die Menge \
von Ereignissen (in unserem Fall alsodie m\[ODoubleDot]glichen \
L\[ADoubleDot]ngen der Introns) recht gro\[SZ] ist: Die empirische Verteilung \
ist quasikontinuierlich.\n\n",
  Cell[BoxData[
      \(TraditionalForm\`\^\(\(18\)\(\ \)\)\)]],
  "Im umgekehrten Fall w\[UDoubleDot]rde die Option ",
  StyleBox["HistogramScale \[Rule] 1",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " im ",
  StyleBox["Histogram",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Befehl zu einer Normierung der Fl\[ADoubleDot]che des Histogramms auf \
Eins f\[UDoubleDot]hren, und Gleichung (2.47) k\[ODoubleDot]nnte direkt \
verwendet werden.\n\n",
  Cell[BoxData[
      \(TraditionalForm\`\^19\)],
    FontSize->13],
  StyleBox[" Die Qualit\[ADoubleDot]t einer solchen Anpassung \
l\[ADoubleDot]sst sich mathematisch weiter untersuchen. Das erforderliche \
Werkzeug ist der ",
    FontSize->13],
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\^2\)]],
  StyleBox["-Test",
    FontSize->13],
  "."
}], "Text",
  CellFrame->{{0, 0}, {0, 0.5}},
  FontFamily->"Times New Roman",
  FontSize->13,
  FontWeight->"Plain"]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
PageWidth->530,
WindowSize->{507, 658},
WindowMargins->{{36, Automatic}, {Automatic, 22}},
Magnification->1
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 553, 21, 115, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2332, 76, 169, 5, 68, "Subtitle"],
Cell[2504, 83, 1970, 50, 168, "Text"],
Cell[4477, 135, 684, 18, 92, "Text"],
Cell[5164, 155, 54, 1, 30, "Input"],
Cell[5221, 158, 803, 21, 50, "Input"],
Cell[6027, 181, 65, 1, 30, "Input"],
Cell[6095, 184, 1880, 61, 129, "Text"],

Cell[CellGroupData[{
Cell[8000, 249, 47, 1, 30, "Input"],
Cell[8050, 252, 169, 2, 29, "Output"]
}, Open  ]],
Cell[8234, 257, 703, 12, 90, "Text"],
Cell[8940, 271, 86, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[9051, 276, 52, 1, 30, "Input"],
Cell[9106, 279, 129, 2, 29, "Output"]
}, Open  ]],
Cell[9250, 284, 102, 2, 33, "Text"],
Cell[9355, 288, 78, 1, 30, "Input"],
Cell[9436, 291, 640, 16, 72, "Text"],
Cell[10079, 309, 85, 1, 30, "Input"],
Cell[10167, 312, 161, 3, 30, "Input"],
Cell[10331, 317, 874, 22, 111, "Text"],
Cell[11208, 341, 114, 3, 70, "Input"],
Cell[11325, 346, 284, 5, 50, "Input"],
Cell[11612, 353, 1949, 47, 149, "Text"],

Cell[CellGroupData[{
Cell[13586, 404, 63, 1, 30, "Input"],
Cell[13652, 407, 56, 1, 29, "Output"]
}, Open  ]],
Cell[13723, 411, 658, 12, 71, "Text"],
Cell[14384, 425, 60, 1, 30, "Input"],
Cell[14447, 428, 157, 3, 30, "Input"],
Cell[14607, 433, 154, 3, 30, "Input"],

Cell[CellGroupData[{
Cell[14786, 440, 112, 2, 30, "Input"],
Cell[14901, 444, 42011, 1523, 186, 13748, 1170, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[56927, 1970, 1470, 22, 147, "Text"],
Cell[58400, 1994, 114, 2, 50, "Input"],
Cell[58517, 1998, 186, 3, 41, "Input"],
Cell[58706, 2003, 144, 4, 33, "Text"],
Cell[58853, 2009, 160, 3, 30, "Input"],

Cell[CellGroupData[{
Cell[59038, 2016, 115, 2, 30, "Input"],
Cell[59156, 2020, 42497, 1538, 186, 13905, 1180, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[101668, 3561, 582, 11, 71, "Text"],
Cell[102253, 3574, 2098, 56, 290, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

